/*  COBERRS.H - COBOL Compiler error definitions

    Copyright (C) 1990-2006 Envyr Corporation.
    All rights reserved.

    This file encompasses the message codes used by the cobol compiler
    and IDE.

    NOTE: As of this file is processed by h2c to build a compiled message
          array for builtin messages and also by icmakems to build
          customized message text in a .ms file.
          As a result, the #defines are limited to simple aliases or equates
          to a numeric value.
          If the define is of the form #define <name> <number> <comment>
          and <comment> starts with MSG, it is taken as a message definition,
          with the message text as a quoted string (C conventions).

    NOTE WELL:
          When customizing message text, only the text should be changed,
          never the numeric value of the message.  The customized messages
          will be in a file named coberrs.ms.
*/

/****************************************************************/
/*                                                              */
/*    cobol error group (CE_xxx) - 1024-2047                    */
/*                                                              */
/****************************************************************/


#define CE_0                1024
#define CE_1                1025
#define CE_2                1026
#define CE_3                1027
#define CE_COPY_LEVELS      1028    /* MSG "Maximum COPY nesting count exceeded" */
#define CE_MAX_LINES        1029    /* MSG "Maximum number of source lines has been exceeded" */
#define CE_SRC_FILES        1030    /* MSG "Maximum number of source files has been exceeded" */
#define CE_BAD_IND          1031    /* MSG "Bad indicator area character; character treated as space" */
#define CE_CONT_EMPTY       1032    /* MSG "The indicator '-' is not allowed on a blank line; indicator ignored" */
#define CE_CONT_AREA        1033    /* MSG "Area A of a continuation line must be blank; used Area B" */
#define CE_CONT_LIT         1034    /* MSG "Continuation of a non-numeric or hexadecimal literal requires a quote here" */
#define CE_CONT_COMMENT     1035    /* MSG "The indicator '-' is not allowed in a comment entry" */
#define CE_EXPECT_PIC       1036    /* MSG "A picture-string is expected here" */
#define CE_EXPECT_SPC       1037    /* MSG "A space is expected here" */
#define CE_ARITH_SPC        1038    /* MSG "A space is required before and after an arithmetic operator" */
#define CE_MAX_LINES_SRC    1039    /* MSG "Maximum number of lines in a single source file has been exceeded" */
#define CE_ILL_CHAR         1040    /* MSG "Invalid character in source.  Character ignored" */
#define CE_BAD_LIT          1041    /* MSG "Invalid non-numeric literal or improper continuation" */
#define CE_LIT_LEN          1042    /* MSG "Non-numeric literal is too long" */
#define CE_NAME_LEN         1043    /* MSG "Item is longer than allowed by ANSI COBOL (30)" */
#define CE_TEXT_LEN         1044    /* MSG "Item is too long" */
#define CE_NUM_LEN          1045    /* MSG "Numeric constant has too many digits" */
#define CE_SYM_SPACE        1046    /* MSG "No more compiler symbol table space" */
#define CE_LIT_SPACE        1047    /* MSG "No more compiler literal space" */
#define CE_ID_SPACE         1048    /* MSG "No more compiler name space" */
#define CE_EXPECT           1049    /* MSG "The following element was expected here" */
#define CE_EXPECT_PER       1050    /* MSG "The separator period was expected here" */
#define CE_RESUME_HERE      1051    /* MSG "The syntaxer is resuming here" */
#define CE_28               1052
#define CE_29               1053
#define CE_EOF              1054    /* MSG "The end of file was reached unexpectedly" */
#define CE_UNREC_WORD       1055    /* MSG "Unrecognized word, probably invalid characters or missing separators" */
#define CE_UNIMPL           1056    /* MSG "Unimplemented feature" */
#define CE_33               1057
#define CE_34               1058
#define CE_IDENT_DIV        1059    /* MSG "Identification Division Header expected here" */
#define CE_36               1060
#define CE_EXP_REC_DESC     1061    /* MSG "The element 'record-description-entry' is expected here" */
#define CE_EXP_PGM_ID       1062    /* MSG "Program-Id Paragraph is expected here" */
#define CE_EXP_EOF          1063    /* MSG "End of File is expected here" */
#define CE_EXP_PGM_NAME     1064    /* MSG "The element 'program-name' is expected here" */
#define CE_41               1065
#define CE_MEM_CLAUSE       1066    /* MSG "WORDS, CHARACTERS, or MODULES expected here" */
#define CE_EXP_AB_NAME      1067    /* MSG "The element 'alphabet-name' is expected here" */
#define CE_EXP_MNEM_NAME    1068    /* MSG "The element 'mnemonic-name' is expected here" */
#define CE_EXP_COND_NAME    1069    /* MSG "The element 'condition-name' is expected here" */
#define CE_46               1070
#define CE_EXP_LIT          1071    /* MSG "The element 'literal' is expected" */
#define CE_EXP_ON_OFF       1072    /* MSG "An ON or OFF clause is expected" */
#define CE_49               1073
#define CE_SAME_AREA        1074    /* MSG "This file already occurs in a SAME AREA clause" */
#define CE_EXP_FILE_NAME    1075    /* MSG "The element 'file-name' is expected here" */
#define CE_EXP_ASSIGN       1076    /* MSG "ASSIGN device type or system filename expected here" */
#define CE_EXP_NAME         1077    /* MSG "The element 'data-name' is expected here" */
#define CE_EXP_INT          1078    /* MSG "The element 'integer' is expected here" */
#define CE_EXP_ORG          1079    /* MSG "An ORGANIZATION specifier is expected here" */
#define CE_EXP_ACCESS       1080    /* MSG "An ACCESS specifier is expected here" */
#define CE_EXP_DELIM        1081    /* MSG "A RECORD DELIMITER specifier is expected here" */
#define CE_INS_EXPECTED     1082    /* MSG "Inserting expected element" */
#define CE_DEL_UNEXPECTED   1083    /* MSG "Deleting unexpected element" */
#define CE_INT_ERROR        1084    /* MSG "Internal Compiler Error" */
#define CE_REC_OPT          1085    /* MSG "RECORD [IS] or RECORDS [ARE] is expected here" */
#define CE_LABEL_TYPE       1086    /* MSG "STANDARD or OMITTED is expected here" */
#define CE_USAGE_OPT        1087    /* MSG "USAGE type is expected here" */
#define CE_SIGN_OPT         1088    /* MSG "LEADING or TRAILING is expected here" */
#define CE_EXP_INDEX        1089    /* MSG "The element 'index-name' is expected here" */
#define CE_EXP_AB_OPT       1090    /* MSG "An alphabet specifier is expected here" */
#define CE_COND_VALUE       1091    /* MSG "VALUE [IS] or VALUES [ARE] is expected here" */
#define CE_FIG_LIT          1092    /* MSG "Figurative constant or nonnumeric literal is expected here" */
#define CE_PIC_LEN          1093    /* MSG "The picture-string is too long" */
#define CE_EXP_ID           1094    /* MSG "The element 'identifier' or 'id' is expected here" */
#define CE_EXP_ID_LIT       1095    /* MSG "The element 'id-lit' is expected here" */
#define CE_PIC_TO_FR_USG    1096    /* MSG "PICTURE requires TO, FROM, or USING, and vice-versa" */
#define CE_COL_OPT          1097    /* MSG "A column positioning specifier is expected here" */
#define CE_LINE_OPT         1098    /* MSG "A line positioning specifier is expected here" */
#define CE_BLANK_OPT        1099    /* MSG "LINE, SCREEN, REMAINDER, or [WHEN] ZERO is expected here" */
#define CE_REC_MODE_OPT     1100    /* MSG "A valid RECORDING MODE option is expected here: FIXED, VARIABLE, etc." */
#define CE_EXP_SUBSCR       1101    /* MSG "Subscript specifier expected here" */
#define CE_EXP_SEC_PAR      1102    /* MSG "A section or paragraph is expected here" */
#define CE_EXP_DECL_SEC     1103    /* MSG "A DECLARATIVES section is expected here" */
#define CE_USE_STMT         1104    /* MSG "A USE statement is expected here" */
#define CE_EXC_OR_ERR       1105    /* MSG "EXCEPTION or ERROR is expected here" */
#define CE_USE_OPT          1106    /* MSG "A USE statement option is expected here" */
#define CE_ACC_SYS_OPT      1107    /* MSG "An ACCEPT .. FROM option is expected here" */
#define CE_SCRN_POS_OPT     1108    /* MSG "A LINE or COLUMN positioning option is expected here" */
#define CE_85               1109
#define CE_EXP_STMT         1110    /* MSG "A statement is expected here" */
#define CE_ADD_TO_GIVING    1111    /* MSG "TO or GIVING is expected here" */
#define CE_88               1112
#define CE_INTO_BY          1113    /* MSG "INTO or BY is expected here" */
#define CE_EXP_DEPENDING    1114    /* MSG "DEPENDING is expected here" */
#define CE_EXP_CONDITION    1115    /* MSG "A condition is expected here" */
#define CE_EXP_IF_BODY      1116    /* MSG "NEXT SENTENCE or a statement list is expected here" */
#define CE_EXP_ELSE         1117    /* MSG "END-IF, ELSE, or end of sentence is expected here" */
#define CE_EXP_ARITH_EXP    1118    /* MSG "An arithmetic expression is expected here" */
#define CE_EXP_TALLY_REP    1119    /* MSG "TALLYING or REPLACING is expected here" */
#define CE_TALLY_BEF_REP    1120    /* MSG "The TALLYING clause must be before the REPLACING clause" */
#define CE_EXP_TALLY_FOR    1121    /* MSG "FOR is expected here" */
#define CE_EXP_C_A_L        1122    /* MSG "CHARACTERS, ALL, or LEADING is expected here" */
#define CE_EXP_C_A_L_F      1123    /* MSG "CHARACTERS, ALL, LEADING, or FIRST is expected here" */
#define CE_EXP_SEC_NAME     1124    /* MSG "A section name is expected here" */
#define CE_EXP_PAR_NAME     1125    /* MSG "A paragraph name is expected here" */
#define CE_EXP_OPEN_OPT     1126    /* MSG "INPUT, OUTPUT, I-O, or EXTEND is expected here" */
#define CE_EXP_VAR_PART     1127    /* MSG "The VARYING or AFTER identifier is expected here" */
#define CE_EXP_REC_NAME     1128    /* MSG "The element 'record-name' is expected here" */
#define CE_EXP_SET_OPT      1129    /* MSG "TO, UP, or DOWN is expected here" */
#define CE_START_OPT        1130    /* MSG "A START relation operator is expected here" */
#define CE_EXP_TERM         1131    /* MSG "A Unary + or -, 'id-lit', or '(' is expected here" */
#define CE_EXP_FACTOR       1132    /* MSG "The element 'id-lit' or '(' is expected here" */
#define CE_EXP_COND         1133    /* MSG "A relation, class test, or sign test is expected here" */
#define CE_EXP_COND_EXP     1134    /* MSG "A condition or conditional expression is expected here" */
#define CE_EXP_COND_TERM    1135    /* MSG "A NOT or simple condition is expected here" */
#define CE_EXP_COND_FACT    1136    /* MSG "A simple condition or '(' is expected here" */
#define CE_EXP_REL_OP       1137    /* MSG "A relation is expected here" */
#define CE_SYM_DEFINED      1138    /* MSG "The symbol is already defined" */
#define CE_SWITCH_LIT       1139    /* MSG "The switch literal is too long or contains invalid characters" */
#define CE_QUAL_DEPTH       1140    /* MSG "Too many levels of qualification have been specified" */
#define CE_NOT_ALPHABET     1141    /* MSG "The symbol is already defined and is not an alphabet" */
#define CE_AB_SYMB_INT_LIT  1142    /* MSG "This must be an unsigned integer from 1 to 256" */
#define CE_ONE_CHR_LIT      1143    /* MSG "This literal must contain just a single character" */
#define CE_AB_USED          1144    /* MSG "This value overlaps with previously specified values" */
#define CE_BAD_CUR_CHR      1145    /* MSG "This character cannot be used as a currency character" */
#define CE_DUPL_FCTL        1146    /* MSG "Duplicate or conflicting file-control clause" */
#define CE_DUPL_ASSIGN      1147    /* MSG "Duplicate or conflicting option in ASSIGN clause" */
#define CE_SYM_UNDEF        1148    /* MSG "The symbol is not defined" */
#define CE_KEY_COUNT        1149    /* MSG "Too many record keys or alternate keys have been specified" */
#define CE_SEQ_FCTL         1150    /* MSG "Invalid file-control clause for a SEQUENTIAL file" */
#define CE_REL_FCTL         1151    /* MSG "Invalid file-control clause for a RELATIVE file" */
#define CE_ISAM_FCTL        1152    /* MSG "Invalid file-control clause for an ANSI INDEXED file" */
#define CE_REL_KEY_REQD     1153    /* MSG "RELATIVE KEY is required for RANDOM or DYNAMIC access" */
#define CE_REL_ASSIGN       1154    /* MSG "A RELATIVE file may only specify ASSIGN TO DISK" */
#define CE_ISAM_ASSIGN      1155    /* MSG "An INDEXED file may only specify ASSIGN TO DISK" */
#define CE_ISAM_PRIM_KEY    1156    /* MSG "The RECORD KEY clause is required for an INDEXED file" */
#define CE_SAME_REC_AREA    1157    /* MSG "This file already occurs in a SAME RECORD AREA clause" */
#define CE_NO_ASSIGN        1158    /* MSG "The ASSIGN clause was not specified" */
#define CE_NO_FCTL          1159    /* MSG "No file-control entry was defined for this file" */
#define CE_DUPL_FDES        1160    /* MSG "Duplicate or conflicting clause in file-description" */
#define CE_INT_GT_0         1161    /* MSG "The value must be an integer greater than zero" */
#define CE_MAX_GE_MIN       1162    /* MSG "Maximum must be greater than or equal to minimum" */
#define CE_BAD_IS           1163    /* MSG "This item is not a valid INFOS STATUS data-item" */
#define CE_ILL_REC_MODE     1164    /* MSG "Invalid RECORDING MODE for file type" */
#define CE_REC_LT_MIN       1165    /* MSG "The record is smaller than the minimum size specified" */
#define CE_REC_GT_MAX       1166    /* MSG "The record is larger than the maximum size specified" */
#define CE_BAD_FD_ITEM      1167    /* MSG "The item does not meet all of the data type, size, or storage requirements" */
#define CE_SEL_NO_FD        1168    /* MSG "The file does not have an FD" */
#define CE_BAD_LEVEL        1169    /* MSG "Level number must be 1 or 2 digits: 01-49, 66, 77, or 88" */
#define CE_146              1170
#define CE_77_FILE          1171    /* MSG "Level 77 items are not allowed in the FILE SECTION" */
#define CE_77_SCRN          1172    /* MSG "Level 77 items are not allowed in the SCREEN SECTION" */
#define CE_88_SCRN          1173    /* MSG "Level 88 items are not allowed in the SCREEN SECTION" */
#define CE_66_SCRN          1174    /* MSG "Level 66 items are not allowed in the SCREEN SECTION" */
#define CE_SYM_CONFLICT     1175    /* MSG "Use of the name conflicts with a previous definition" */
#define CE_NO_REDEF         1176    /* MSG "REDEFINES is not allowed at level 01 in the the FILE SECTION" */
#define CE_REDEF_NOT_FND    1177    /* MSG "REDEFINES object was not found" */
#define CE_REDEF_LEV        1178    /* MSG "REDEFINES object level number does not match" */
#define CE_REDEF_OCCURS     1179    /* MSG "REDEFINES object may not have the OCCURS phrase" */
#define CE_REDEF_VAR_OC     1180    /* MSG "REDEFINES subject and object may not have variable occurrence" */
#define CE_REDEF_TYPE       1181    /* MSG "REDEFINES object must be a data-name or record-name" */
#define CE_REDEF_DATA       1182    /* MSG "REDEFINES subject and object have intervening storage" */
#define CE_159              1183
#define CE_ILL_LEVEL        1184    /* MSG "Invalid level number - improper nesting of group items" */
#define CE_MISSING_01       1185    /* MSG "Invalid level number - 01 level item is missing" */
#define CE_BAD_RENAMES      1186    /* MSG "A level 66 item must follow the last record entry" */
#define CE_COND_66          1187    /* MSG "A condition-name cannot be defined for a level 66 item" */
#define CE_COND_NONE        1188    /* MSG "The condition-name must follow a data element" */
#define CE_NOT_UNIQUE       1189    /* MSG "This name cannot be made unique through qualification" */
#define CE_DUPL_DESCR       1190    /* MSG "Duplicate or conflicting data description clause; clause ignored" */
#define CE_OCCURS_INT       1191    /* MSG "The occurs count is out of range" */
#define CE_VALUE_FILE       1192    /* MSG "The VALUE clause is not allowed in the FILE SECTION" */
#define CE_VALUE_LINK       1193    /* MSG "The VALUE clause is not allowed in the LINKAGE SECTION" */
#define CE_ILL_CHR_PIC      1194    /* MSG "Invalid character in PICTURE string" */
#define CE_BAD_REP_PIC      1195    /* MSG "Invalid repetition count value in picture-string" */
#define CE_INV_REP_PIC      1196    /* MSG "A repetition count may not follow S, V, CR, DB or decimal-point" */
#define CE_INVALID_PIC      1197    /* MSG "This is not a valid picture-string" */
#define CE_SIZE_PIC         1198    /* MSG "The internal encoded picture-string is too long" */
#define CE_INV_NUM_PIC      1199    /* MSG "This is not a valid numeric picture-string" */
#define CE_NO_DIGITS_PIC    1200    /* MSG "The picture does not specify any numeric digit positions" */
#define CE_DEC_PREC_PIC     1201    /* MSG "The maximum total precision allowed is 18 digits" */
#define CE_DATA_SIZE        1202    /* MSG "This item exceeds the maximum data storage size limit" */
#define CE_INV_AZ_PIC       1203    /* MSG "Invalid combination of zero suppression ('*' and 'Z')" */
#define CE_CONF_SIGN_PIC    1204    /* MSG "Conflicting use of sign symbols ('+', '-', 'CR', 'DB')" */
#define CE_CR_DB_PIC        1205    /* MSG "Invalid use or placement of 'CR' or 'DB'" */
#define CE_P_DEC_PIC        1206    /* MSG "Conflicting use of 'P' and explicit decimal point" */
#define CE_FLT_SIGN_PIC     1207    /* MSG "Invalid use of fixed or floating insertion '+' or '-'" */
#define CE_FLT_CUR_PIC      1208    /* MSG "Invalid use of fixed or floating insertion currency symbol" */
#define CE_SIGN_CUR_PIC     1209    /* MSG "Invalid combination of sign symbol and currency symbol" */
#define CE_DUPL_DEC_PIC     1210    /* MSG "Duplicate specification of implicit or explicit decimal point" */
#define CE_AZ_FLT_PIC       1211    /* MSG "Conflicting use of floating insertion and zero suppression" */
#define CE_INV_P_PIC        1212    /* MSG "Invalid 'P' scaling specification" */
#define CE_INV_CUR_PIC      1213    /* MSG "Invalid use or placement of currency symbol" */
#define CE_FLT_RT_PIC       1214    /* MSG "Invalid floating insertion to right of decimal point" */
#define CE_AZ_RT_PIC        1215    /* MSG "Invalid zero suppression to right of decimal point" */
#define CE_PIC_W_INX        1216    /* MSG "The PICTURE clause may not be specified with USAGE INDEX" */
#define CE_SIGN_W_INX       1217    /* MSG "The SIGN clause may not be specified with USAGE INDEX" */
#define CE_JUST_W_INX       1218    /* MSG "The JUSTIFIED clause may not be specified with USAGE INDEX" */
#define CE_B_Z_W_INX        1219    /* MSG "The BLANK WHEN ZERO clause may not be specified with USAGE INDEX" */
#define CE_VAL_W_INX        1220    /* MSG "The VALUE clause may not be specified with USAGE INDEX" */
#define CE_SYNC_W_INX       1221    /* MSG "The SYNCHRONIZED clause may not be specified with USAGE INDEX" */
#define CE_JUST_W_GRP       1222    /* MSG "The JUSTIFIED clause may not be specified for a group item" */
#define CE_B_Z_W_GRP        1223    /* MSG "The BLANK ZERO clause may not be specified for a group item" */
#define CE_SYNC_W_GRP       1224    /* MSG "The SYNCHRONIZED clause may not be specified for a group item" */
#define CE_PIC_REQ_77       1225    /* MSG "The PICTURE or USAGE INDEX clause must be specified for a level 77 item" */
#define CE_01_77_OCC        1226    /* MSG "The OCCURS clause may not be specified for 01 or 77 level items" */
#define CE_USG_NUM          1227    /* MSG "USAGE BINARY, COMP, PACKED-DECIMAL, COMP-3 or COMP-5 can only be used with a numeric item" */
#define CE_USG_FATHER       1228    /* MSG "The USAGE must match the USAGE of the containing group item" */
#define CE_NEED_S           1229    /* MSG "The SIGN clause may not be used unless the PICTURE contains an 'S'" */
#define CE_SIGN_U_DISP      1230    /* MSG "The SIGN clause may only be used with item whose USAGE is DISPLAY" */
#define CE_SIGN_NUM_GRP     1231    /* MSG "The SIGN clause may only be specified on a group or numeric item" */
#define CE_B0_NUM_ED        1232    /* MSG "The BLANK WHEN ZERO clause may only be specified for a numeric or numeric-edited item" */
#define CE_JUST_NUM_ED      1233    /* MSG "The JUSTIFIED clause may not be specified for a numeric, floating point or edited item" */
#define CE_VAL_REDEF        1234    /* MSG "The VALUE clause may not be used with REDEFINES or in a REDEFINES group" */
#define CE_VAL_FATHER       1235    /* MSG "The VALUE clause is invalid within a group that has the VALUE clause" */
#define CE_B0_SIGNED        1236    /* MSG "The BLANK WHEN ZERO clause may not be specified for a signed numeric item" */
#define CE_SIGN_B0          1237    /* MSG "The SIGN clause may not be used with BLANK WHEN ZERO" */
#define CE_MAKE_AMBIG       1238    /* MSG "Use of the name will make an 01 or 77 level item non-unique" */
#define CE_REDEF_GT         1239    /* MSG "The REDEFINES subject is larger than the object" */
#define CE_JUST_VAL         1240    /* MSG "The JUSTIFIED clause is invalid within a group that has the VALUE clause" */
#define CE_SYNC_VAL         1241    /* MSG "The SYNCHRONIZED clause is invalid within a group that has the VALUE clause" */
#define CE_USG_VAL          1242    /* MSG "USAGE (other than DISPLAY) is invalid within a group that has the VALUE clause" */
#define CE_BAD_QUAL         1243    /* MSG "Symbol in qualifier list is undefined" */
#define CE_AMBIG_QUAL       1244    /* MSG "Symbol is not uniquely qualified" */
#define CE_NO_MATCH         1245    /* MSG "The symbol (as qualified) was not found" */
#define CE_BAD_FS           1246    /* MSG "This item is not a valid FILE STATUS data-item" */
#define CE_BAD_RELKEY       1247    /* MSG "This item is not a valid RELATIVE KEY data-item" */
#define CE_BAD_KEY          1248    /* MSG "This item is not a valid KEY or ALTERNATE KEY data-item" */
#define CE_KEY_LEN          1249    /* MSG "This key exceeds the maximum key length allowed" */
#define CE_KEY_IN_REC       1250    /* MSG "This key is not in a record for the same file" */
#define CE_SAME_KEY_OFS     1251    /* MSG "This key has the same offset in the record as another key" */
#define CE_DS_RECLEN        1252    /* MSG "The record length exceeds the system maximum for a data-sensitive SEQUENTIAL file" */
#define CE_SEQ_RECLEN       1253    /* MSG "The record length exceeds the system maximum for a SEQUENTIAL file" */
#define CE_REL_RECLEN       1254    /* MSG "The record length exceeds the system maximum for a RELATIVE file" */
#define CE_ISAM_RECLEN      1255    /* MSG "The record length exceeds the system maximum for an INDEXED file" */
#define CE_DEC_PREC_NUM     1256    /* MSG "The maximum total precision allowed in a numeric literal is 18 digits" */
#define CE_TRUNC_LEFT       1257    /* MSG "The value had nonzero digits truncated to the left of the decimal point" */
#define CE_TRUNC_RIGHT      1258    /* MSG "The value had nonzero digits truncated to the right of the decimal point" */
#define CE_TRUNC_BOTH       1259    /* MSG "The value had nonzero digits truncated to the left and right of the decimal point" */
#define CE_INV_VAL_TYPE     1260    /* MSG "The type of literal is not valid for the type of the data item" */
#define CE_VAL_LEN          1261    /* MSG "The VALUE literal may not be longer than the data item" */
#define CE_DG_S_IN_SCRN     1262    /* MSG "Code was generated the same as 1.xx ICOBOL (which ignores S in picture)" */
#define CE_PIC_AND_VAL      1263    /* MSG "The PICTURE and VALUE clauses may not both be specified" */
#define CE_DUPL_SCRN        1264    /* MSG "Duplicate or conflicting screen description clause" */
#define CE_REL_ABS_SCRN     1265    /* MSG "Relative positioning may not be used after variable positioning" */
#define CE_242              1266
#define CE_LC_VAL           1267    /* MSG "The LINE or COLUMN value must be from 1 to 127" */
#define CE_LC_PLUS_VAL      1268    /* MSG "The LINE PLUS or COLUMN PLUS value must be from 0 to 255" */
#define CE_LC_OVFL          1269    /* MSG "The computed starting line or column position exceeds 127" */
#define CE_FLD_OVFL         1270    /* MSG "The end of the field is past column 255" */
#define CE_SUB_NON_GRP      1271    /* MSG "The level number may increase only after a group item" */
#define CE_NOT_DATA         1272    /* MSG "This item is not a data-item" */
#define CE_INCOMP_TO        1273    /* MSG "The TO and PICTURE items are not compatible" */
#define CE_INCOMP_FROM      1274    /* MSG "The FROM and PICTURE items are not compatible" */
#define CE_INCOMP_USING     1275    /* MSG "The USING and PICTURE items are not compatible" */
#define CE_GRP_T_U_SCRN     1276    /* MSG "This option may only be used with a group, TO, or USING" */
#define CE_JUST_FR_USG      1277    /* MSG "JUSTIFIED may only be used with FROM or USING" */
#define CE_254              1278
#define CE_COPY_INDEXED     1279    /* MSG "The INDEXED option is not supported; it is ignored" */
#define CE_COPY_NAME        1280    /* MSG "A 'text-name' or non-numeric literal specifying the COPY filename is required here" */
#define CE_EXP_OVRFL        1281    /* MSG "The level 88, arithmetic, or conditional expression is too complex" */
#define CE_258              1282
#define CE_259              1283
#define CE_NOT_SUBSCR       1284    /* MSG "This item may not be subscripted" */
#define CE_FEW_SUBSCR       1285    /* MSG "Not enough subscripts were specified; supplying 1's" */
#define CE_REQ_SUBSCR       1286    /* MSG "This item must be subscripted" */
#define CE_TYPE_SUBSCR      1287    /* MSG "The item must be a numeric integer, USAGE INDEX, or an index-name" */
#define CE_NUM_SUBSCR       1288    /* MSG "Too many subscripts have been specified for this item" */
#define CE_IGN_SUBSCR       1289    /* MSG "This subscript and those following are being ignored" */
#define CE_INX_SUBSCR       1290    /* MSG "This index-name is not listed in a corresponding INDEXED BY list" */
#define CE_DIMS_SUBSCR      1291    /* MSG "The total number of dimensions allowable has been exceeded" */
#define CE_USING_TYPE       1292    /* MSG "The USING item must be a data-name" */
#define CE_USING_SEC        1293    /* MSG "The USING item must be defined in the LINKAGE SECTION" */
#define CE_USING_LEVEL      1294    /* MSG "The USING item must be level 01 or 77" */
#define CE_USING_REDEF      1295    /* MSG "The USING item must not be REDEFINE'd on another item" */
#define CE_USING_CNT        1296    /* MSG "The number of items in the USING list exceeds the compiler limit" */
#define CE_USING_USED       1297    /* MSG "The USING item has already been specified in the USING list" */
#define CE_DUPL_USE         1298    /* MSG "A DECLARATIVES section for this USE has already been specified" */
#define CE_NOT_PROC         1299    /* MSG "The item is not a paragraph or section name" */
#define CE_QUAL_NO_SEC      1300    /* MSG "Paragraph names may not be qualified unless the program has sections" */
#define CE_BZ_REQ_ZERO      1301    /* MSG "The keyword ZERO, not ZEROS or ZEROES, must be used here" */
#define CE_INT_RANGE        1302    /* MSG "The integer value is out of range" */
#define CE_279              1303
#define CE_STMT_NEST        1304    /* MSG "The maximum nesting of conditional statements has been exceeded" */
#define CE_ILL_SYS_ACC      1305    /* MSG "The data item is not MOVE compatible with the system value" */
#define CE_ILL_MOVE         1306    /* MSG "Illegal combination of data items in MOVE" */
#define CE_INT_ID_LIT       1307    /* MSG "This item must be an integer-valued 'id-lit'" */
#define CE_INP_FIELDS       1308    /* MSG "This screen or sub-screen has no input fields" */
#define CE_NEED_SCRN        1309    /* MSG "This phrase can only be used with a screen-name" */
#define CE_OPND_TYPE        1310    /* MSG "The operand is the wrong class or type for the operation" */
#define CE_INT_ID           1311    /* MSG "This item must refer to an elementary integer data item" */
#define CE_EXTRA_RPAREN     1312    /* MSG "Unbalanced parentheses; right parenthesis is being ignored" */
#define CE_NEXT_SENT        1313    /* MSG "When END-IF is specified, NEXT SENTENCE should not be specified (ANSI)" */
#define CE_PERF_VAR_NEST    1314    /* MSG "To many AFTER phrases have been specified" */
#define CE_NUM_OR_INX       1315    /* MSG "A numeric item or index-name is required" */
#define CE_INX_DIF_TBLS     1316    /* MSG "The AFTER/VARYING index-name and FROM index-name reference different tables" */
#define CE_NUM_ID_LIT       1317    /* MSG "A numeric identifier or literal is required" */
#define CE_NON_ZERO         1318    /* MSG "A non-zero value is required here" */
#define CE_STMT_LAST        1319    /* MSG "This statement must be the last statement in the sentence" */
#define CE_EXIT_ALONE       1320    /* MSG "The EXIT statement must be the only sentence in a paragraph" */
#define CE_DIFF_SEC         1321    /* MSG "A GO TO statement may not branch between declarative and non-declarative procedures" */
#define CE_DIFF_DECL_SEC    1322    /* MSG "A GO TO statement may not branch from one declaratives section to another" */
#define CE_END_BEF_BEG      1323    /* MSG "The end of the PERFORM range does not follow the beginning in the source" */
#define CE_NOT_GROUP        1324    /* MSG "This item is not a group item" */
#define CE_NOT_DATA_LIT     1325    /* MSG "This item is not a data item or literal" */
#define CE_INV_USE_INX      1326    /* MSG "This is an invalid use of an index-name or index data item" */
#define CE_NO_CORR_OPNDS    1327    /* MSG "There are no items that correspond" */
#define CE_COMPOSITE        1328    /* MSG "The composite of operands is greater than 18 digits" */
#define CE_NUM_ID           1329    /* MSG "An elementary numeric data-item is required here" */
#define CE_NUM_OR_ED_ID     1330    /* MSG "An elementary numeric or numeric-edited data-item is required here" */
#define CE_NOT_USG_DISP     1331    /* MSG "The item is not USAGE DISPLAY" */
#define CE_ELEM_ID_LIT      1332    /* MSG "The item is not an elementary data-item, non-numeric literal, or figurative constant" */
#define CE_INS_EQ_LEN       1333    /* MSG "The lengths of the two operands in the BY or TO clause must be equal" */
#define CE_STR_OPNDS        1334    /* MSG "The compiler limit on the number of INSPECT/STRING/UNSTRING clauses has been exceeded" */
#define CE_NOT_ELEM         1335    /* MSG "The item must be an elementary item, not a group item" */
#define CE_312              1336
#define CE_NOT_W_SCRN       1337    /* MSG "This phrase is not valid with a screen-name" */
#define CE_SCRN_NAME        1338    /* MSG "The item is not a screen-name" */
#define CE_INV_SEQ_ORG      1339    /* MSG "The clause/statement is not valid for a SEQUENTIAL file" */
#define CE_INV_REL_ORG      1340    /* MSG "The clause/statement is not valid for a RELATIVE file" */
#define CE_INV_ISAM_ORG     1341    /* MSG "The clause/statement is not valid for an ANSI INDEXED file" */
#define CE_INV_OP_DEV       1342    /* MSG "This operation is not valid for the ASSIGN'ed device" */
#define CE_DUPL_STMT        1343    /* MSG "Duplicate or conflicting statement clause" */
#define CE_NOT_RECORD       1344    /* MSG "The item is not a record-name" */
#define CE_INV_SEQ_ACC      1345    /* MSG "The clause is not valid for a file with SEQUENTIAL access" */
#define CE_INV_RAN_ACC      1346    /* MSG "The clause is not valid for a file with RANDOM access" */
#define CE_INV_DYN_ACC      1347    /* MSG "The clause is not valid for a file with DYNAMIC access" */
#define CE_START_NO_KEY     1348    /* MSG "The file must specify a RELATIVE KEY in order to use START" */
#define CE_START_REL_KEY    1349    /* MSG "The data-name must be the same as the RELATIVE KEY data name" */
#define CE_NOT_A_KEY        1350    /* MSG "The data-name does not correspond to any of the keys" */
#define CE_SAME_AS_REC      1351    /* MSG "This item occupies the same storage as the data record" */
#define CE_REQ_INV_KEY      1352    /* MSG "The INVALID KEY clause is required (no applicable USE procedure)" */
#define CE_MAY_INV_KEY      1353    /* MSG "The INVALID KEY clause may be required (applicable USE procedure depends on OPEN mode)" */
#define CE_REQ_AT_END       1354    /* MSG "The AT END clause is required (no applicable USE procedure)" */
#define CE_MAY_AT_END       1355    /* MSG "The AT END clause may be required (applicable USE procedure depends on OPEN mode)" */
#define CE_AT_END_RAN       1356    /* MSG "The AT END clause may not be specified for a random (keyed) READ" */
#define CE_INV_DYN_SEQ      1357    /* MSG "The clause is not valid for a sequential operation on a file with DYNAMIC access" */
#define CE_NO_ADV_LAST      1358    /* MSG "The last item was a screen-name, NO ADVANCING is being ignored" */
#define CE_NUM_OPND         1359    /* MSG "A numeric id-lit or expression is expected here" */
#define CE_336              1360
#define CE_337              1361
#define CE_REL_LEFT_OPND    1362    /* MSG "The subject operand of the relational operator is missing" */
#define CE_DEAD_SEC         1363    /* MSG "This section is unreachable; the entire section has been eliminated" */
#define CE_DEAD_PAR         1364    /* MSG "This paragraph is unreachable; the entire paragraph has been eliminated" */
#define CE_DEAD_STMT        1365    /* MSG "This statement is unreachable; it (and possibly others following) has been eliminated" */
#define CE_DEAD_PERF        1366    /* MSG "This paragraph is the end of a PERFORM range, but the end of the paragraph is unreachable" */
#define CE_UNREF_ITEM       1367    /* MSG "This item is never referenced" */
#define CE_REF_RECD         1368    /* MSG "One or more records of this file are referenced, but the file is never referenced" */
#define CE_MAX_DATA_SZ      1369    /* MSG "The maximum program data area size has been exceeded" */
#define CE_MAX_CODE_SZ      1370    /* MSG "The maximum program code area size has been exceeded" */
#define CE_OPEN_EXT_SEQ     1371    /* MSG "OPEN EXTEND is supported only for SEQUENTIAL files" */
#define CE_DEAD_END_PERF    1372    /* MSG "The end of the PERFORM range is unreachable, this is effectively a GO TO" */
#define CE_P_V_SCRN         1373    /* MSG "This option may only be used with a PICTURE or VALUE clause" */
#define CE_RESV_WORD        1374    /* MSG "This word is a reserved word in some other compatibility mode" */
#define CE_POS_INT          1375    /* MSG "The value must be a positive integer" */
#define CE_DG_INS_TAL       1376    /* MSG "Code was generated the same as 1.xx ICOBOL (which resets the TALLY variable to zero)" */
#define CE_DG_DUPL_ALT      1377    /* MSG "Code was generated the same as 1.xx ICOBOL (which always allows DUPLICATES)" */
#define CE_IMPLY_LC_SCRN    1378    /* MSG "An implied line/column position cannot follow a variable line/column" */
#define CE_355              1379
#define CE_OBSOLETE         1380    /* MSG "This construct or operation is an obsolete feature of standard COBOL" */
#define CE_357              1381
#define CE_358              1382
#define CE_PARM_REF         1383    /* MSG "Invalid reference to a LINKAGE item (not USING item or redefined on USING item)" */
#define CE_360              1384
#define CE_NO_ALL           1385    /* MSG "The ALL form of figurative constants is not allowed here" */
#define CE_UNSCALE_INT      1386    /* MSG "This numeric item must be an integer, and it may not have P's in its PICTURE" */
#define CE_NOT_EDITED       1387    /* MSG "This data item may not be an edited data item" */
#define CE_NOT_JUST         1388    /* MSG "This data item may not have the JUSTIFIED clause" */
#define CE_PTR_PREC         1389    /* MSG "The item does not have enough precision to hold the maximum length" */
#define CE_NOT_ALPHANUM     1390    /* MSG "The item is not category alphanumeric" */
#define CE_UNSCALE_NUM      1391    /* MSG "This numeric item may not have P's in its PICTURE" */
#define CE_DELIMIT_OPT      1392    /* MSG "A DELIMITED BY option is expected here (SIZE or 'id-lit')" */
#define CE_REQ_DELIM        1393    /* MSG "Use of this phrase requires the DELIMITED BY phrase" */
#define CE_DG_NUM_AN        1394    /* MSG "Code was generated the same as 1.xx ICOBOL (which incorrectly treats signed numeric like alphanumeric)" */
#define CE_CORR_OPND        1395    /* MSG "The following name was matched for CORRESPONDING" */
#define CE_DEF_FNAME        1396    /* MSG "The following external filename was generated" */
#define CE_CANT_RECOVER     1397    /* MSG "The syntaxer is unable to recover and resume syntaxing" */
#define CE_EXP_END_DECL     1398    /* MSG "The END DECLARATIVES header is expected here" */
#define CE_SKIP_TOKENS      1399    /* MSG "The syntaxer is skipping source to attempt error recovery" */
#define CE_EXP_DATA_DESCR   1400    /* MSG "The element 'data-description-entry' is expected here" */
#define CE_EXP_SCRN_DESCR   1401    /* MSG "The element 'screen-description-entry' is expected here" */
#define CE_END_SENT         1402    /* MSG "A new statement or the end of a sentence (period) is expected here" */
#define CE_END_PAR          1403    /* MSG "A new section, paragraph, or sentence is expected here" */
#define CE_USE_OF_VALUES    1404    /* MSG "The word VALUE, not VALUES must be used here" */
#define CE_381              1405
#define CE_382              1406
#define CE_S_IN_SCRN        1407    /* MSG "The 'S' PICTURE character may not be used in the screen section (ignoring it)" */
#define CE_NUM_IN_LIT       1408    /* MSG "The non-numeric literal has an invalid imbedded numeric value (<<xxx> format)" */
#define CE_REDEF_LT         1409    /* MSG "The REDEFINES subject is smaller than the object" */
#define CE_EXP_COM_INIT     1410    /* MSG "COMMON and/or INITIAL is expected here" */
#define CE_EXP_SYMB_CHAR    1411    /* MSG "The element 'symbolic-character' is expected here" */
#define CE_EXP_CLS_NAME     1412    /* MSG "The element 'class-name' is expected here" */
#define CE_EXP_REEL_UNIT    1413    /* MSG "REEL or UNIT is expected here" */
#define CE_OBSOLETE_IGN     1414    /* MSG "This construct is an obsolete feature of standard COBOL; it is being ignored" */
#define CE_391              1415
#define CE_EXP_DATA_LIT     1416    /* MSG "The element 'data-name' or 'literal' is expected here" */
#define CE_EXP_NOREW_LOCK   1417    /* MSG "NO REWIND or LOCK expected here" */
#define CE_UNIMPL_IGN       1418    /* MSG "This construct is not implemented; it is being ignored" */
#define CE_EXP_REF_CONT     1419    /* MSG "REFERENCE or CONTENT is expected here" */
#define CE_EXP_EVAL_SUBJ    1420    /* MSG "An expression, TRUE, or FALSE is expected here" */
#define CE_EXP_EVAL_OBJ     1421    /* MSG "An expression, condition, ANY, TRUE, or FALSE is expected here" */
#define CE_EXP_WHEN         1422    /* MSG "WHEN, END-EVALUATE, or end of sentence is expected here" */
#define CE_EXP_INIT_REPL    1423    /* MSG "A data type specifier is expected here" */
#define CE_EXP_BEF_AFT      1424    /* MSG "BEFORE or AFTER is expected here" */
#define CE_IN_LINE_AFTER    1425    /* MSG "The AFTER phrase is not allowed with in-line PERFORM" */
#define CE_EXP_USING        1426    /* MSG "A USING list item is expected here" */
#define CE_IGN_ITEM         1427    /* MSG "This item is being ignored" */
#define CE_IMPER_STMT       1428    /* MSG "This statement is not an imperative statement" */
#define CE_EXP_UNTIL_VAR    1429    /* MSG "UNTIL or VARYING is expected here" */
#define CE_SYMB_NO_INT      1430    /* MSG "Symbolic Character name has no corresponding integer definition" */
#define CE_SYMB_NO_NAME     1431    /* MSG "Symbolic Character integer value has no corresponding name" */
#define CE_SYMB_BAD_AB      1432    /* MSG "The alphabet cannot be an alphabet defined with the literal phrase" */
#define CE_OCCURS_TO_VAL    1433    /* MSG "The maximum occurrence value must be greater than the minimum" */
#define CE_OCCURS_KEYS      1434    /* MSG "The maximum number of OCCURS KEYS has already been specified" */
#define CE_NESTED_DEP_ON    1435    /* MSG "An OCCURS item cannot have a variable occurrence item subordinate to it" */
#define CE_DEP_ON_LAST      1436    /* MSG "OCCURS..DEPENDING must only be followed by items subordinate to it" */
#define CE_KEY_NO_OCCURS    1437    /* MSG "The KEY item may not contain the OCCURS clause" */
#define CE_KEY_SUBJ_FIRST   1438    /* MSG "Only the first KEY may specify the OCCURS entry" */
#define CE_KEY_NOT_SUB      1439    /* MSG "The KEY item is not subordinate to the OCCURS entry" */
#define CE_INTERVENE_OCC    1440    /* MSG "No OCCURS item may occur between the KEY entry and its OCCURS entry" */
#define CE_BAD_FN           1441    /* MSG "This item is not a valid file-name item" */
#define CE_DEP_OVERLAP      1442    /* MSG "The DEPENDING ON item may not overlap the table in storage" */
#define CE_GRP_OR_PIC       1443    /* MSG "This item needs a PICTURE clause or subordinate items" */
#define CE_EXP_RENAMES      1444    /* MSG "RENAMES is expected here" */
#define CE_RENAMES_01       1445    /* MSG "RENAMES may only be associated with 01 level records" */
#define CE_RENAMES_OBJ      1446    /* MSG "The RENAMES object must be in the immediately preceding record" */
#define CE_RENAMES_LEV      1447    /* MSG "This item must not be level 01, 66, 77, or 88" */
#define CE_RENAMES_OCC      1448    /* MSG "This item must not be contained in or have OCCURS or variable occurrences" */
#define CE_RENAMES_SAME     1449    /* MSG "The two RENAMES objects cannot be the same object" */
#define CE_RENAMES_SPAN     1450    /* MSG "The two RENAMES objects do not specify a proper range" */
#define CE_IMPLY_ITEM       1451    /* MSG "The item is only referenced indirectly (e.g., via REDEFINES)" */
#define CE_STD_ENHANCE      1452    /* MSG "This construct is an enhancement to Standard COBOL" */
#define CE_NEXT_W_ENDIF     1453    /* MSG "NEXT SENTENCE may not be used in an IF that ends with END-IF" */
#define CE_LIT_SS_RANGE     1454    /* MSG "The subscript value is out of range" */
#define CE_OPCODE_LEVEL     1455    /* MSG "This feature is not implemented for the specified code revision" */
#define CE_BAD_FROM_PIC     1456    /* MSG "P, CR, and DB picture characters can only be used in an output-only field" */
#define CE_DG_V_IN_SCRN     1457    /* MSG "Code was generated the same as 1.xx ICOBOL (which ignores V in picture)" */
#define CE_434              1458
#define CE_NO_EXPRS         1459    /* MSG "A numeric expression is not allowed here" */
#define CE_436              1460
#define CE_437              1461
#define CE_438              1462
#define CE_EXP_DATA_COND    1463    /* MSG "A data-name or condition-name is expected here" */
#define CE_EXP_EQUAL_EQ     1464    /* MSG "EQUAL or '=' is expected here" */
#define CE_REQ_OCC_INX      1465    /* MSG "This item must have an OCCURS clause with INDEXED BY" */
#define CE_REQ_OCC_KEY      1466    /* MSG "This item must have an OCCURS clause with KEY IS" */
#define CE_SUB_1ST_INX      1467    /* MSG "This item may not be subscripted by the table's first index-name" */
#define CE_SRCH_KEY_CNT     1468    /* MSG "The SEARCH ALL has too many conditions for the number of keys" */
#define CE_ID_NOT_KEY       1469    /* MSG "This item may not be a KEY IS item of the table being searched" */
#define CE_REQ_1ST_INX      1470    /* MSG "This item must be subscripted by the table's first index-name" */
#define CE_ID_REQ_KEY       1471    /* MSG "The Nth condition's data-name must the Nth KEY IS item" */
#define CE_CN_REQ_KEY       1472    /* MSG "The Nth condition's condition-name must be for the Nth KEY IS item" */
#define CE_CN_SIMPLE        1473    /* MSG "The condition-name must specify a one-item condition" */
#define CE_NEXT_W_ENDSR     1474    /* MSG "NEXT SENTENCE may not be used in a SEARCH that ends with END-SEARCH" */
#define CE_COLOR_OPT        1475    /* MSG "Color specifier expected here" */
#define CE_452              1476
#define CE_COLOR_NUM        1477    /* MSG "Color specifier is out of range" */
#define CE_SCRN_USAGE       1478    /* MSG "The USAGE clause in screens may only be specified for group or data fields" */
#define CE_SCRN_SIGN        1479    /* MSG "The SIGN clause in screens may only be specified for group or data fields" */
#define CE_EOL_GROUP        1480    /* MSG "BLANK LINE and ERASE EOL are not allowed at the group level" */
#define CE_EOS_GROUP        1481    /* MSG "ERASE EOS is not allowed at the group level" */
#define CE_ERL_GROUP        1482    /* MSG "ERASE LINE is not allowed at the group level" */
#define CE_459              1483
#define CE_ACC_DIS_OPNDS    1484    /* MSG "The compiler limit on the number of ACCEPT or DISPLAY arguments has been exceeded" */
#define CE_EXP_FD_OR_SD     1485    /* MSG "An FD or SD is expected here" */
#define CE_EXP_INT_NAME     1486    /* MSG "An integer or data-name specifying an integer is expected here" */
#define CE_EXP_ASC_DESC     1487    /* MSG "ASCENDING or DESCENDING expected here" */
#define CE_EXP_OUT_GIV      1488    /* MSG "OUTPUT or GIVING expected here" */
#define CE_EXP_AT_END       1489    /* MSG "An AT END clause is expected here" */
#define CE_EXP_INP_USG      1490    /* MSG "INPUT or USING expected here" */
#define CE_EXP_TOP_BOT      1491    /* MSG "TOP or BOTTOM is expected here" */
#define CE_SAME_SM_AREA     1492    /* MSG "This file already occurs in a SAME SORT/SORT-MERGE AREA clause" */
#define CE_SD_BAD_SEL       1493    /* MSG "This SELECT is not valid for SORT-MERGE file" */
#define CE_SM_RECLEN        1494    /* MSG "The record length exceeds the system maximum for a SORT/MERGE file" */
#define CE_ILL_LINAGE       1495    /* MSG "The LINAGE clause is only valid for sequential print files" */
#define CE_NEED_SORTMERGE   1496    /* MSG "The file must be a SORT/MERGE file" */
#define CE_KEY_MIN_REC      1497    /* MSG "The key is not contained within the minimum record length" */
#define CE_REPEAT_FILE      1498    /* MSG "The same file-name has been used more than once in the SORT or MERGE" */
#define CE_OVERLAP_AREA     1499    /* MSG "File-name use conflict from use in the SAME AREA clause" */
#define CE_OVERLAP_RECD     1500    /* MSG "File-name use conflict from use in the SAME RECORD AREA clause" */
#define CE_OVERLAP_SM       1501    /* MSG "File-name use conflict from use in the SAME SORT/SORT-MERGE AREA clause" */
#define CE_USG_RECLEN       1502    /* MSG "This file's records cannot be smaller or larger than the SORT/MERGE file" */
#define CE_USG_SEQ_IN       1503    /* MSG "This file must be a sequential file that can be opened for input" */
#define CE_GIV_OUT          1504    /* MSG "This file cannot be opened for output" */
#define CE_FILE_NOT_SM      1505    /* MSG "This file cannot be a SORT or MERGE file" */
#define CE_SM_MISMATCH      1506    /* MSG "The primary key and the first SORT or MERGE key must match" */
#define CE_SM_KEY_ASC       1507    /* MSG "An output file is indexed with an ascending primary key, so this key must be ascending" */
#define CE_SM_NOT_DECL      1508    /* MSG "This statement may not be used in the DECLARATIVES" */
#define CE_REC_NOT_SD       1509    /* MSG "This record is not associated with a sort file" */
#define CE_KEY_OPNDS        1510    /* MSG "The compiler limit on the number of KEY arguments has been exceeded" */
#define CE_BAD_LINAGE       1511    /* MSG "This item is not a valid LINAGE clause data-item" */
#define CE_488              1512
#define CE_OLD_ALPHABET     1513    /* MSG "The ANSI-74 ALPHABET clause should be converted to ANSI-85 syntax" */
#define CE_490              1514
#define CE_START_LONGER     1515    /* MSG "The data-item is longer than any corresponding key" */
#define CE_492              1516
#define CE_493              1517
#define CE_NEED_SEQ         1518    /* MSG "The file must be SEQUENTIAL" */
#define CE_495              1519
#define CE_496              1520
#define CE_EXP_CHAN_NAME    1521    /* MSG "The element 'channel-name' is expected here" */
#define CE_EXP_EVEN_ODD     1522    /* MSG "EVEN or ODD expected here" */
#define CE_499              1523
#define CE_EXP_USER_OPT     1524    /* MSG "VOLUME, HEADER or TRAILER expected here" */
#define CE_EXP_VALUE_OPT    1525    /* MSG "VALUE OF option phrase expected here" */
#define CE_EXP_REC_LEN      1526    /* MSG "RECORD LENGTH clause is expected here" */
#define CE_EXP_SUB_DUPL     1527    /* MSG "SUB-INDEX or DUPLICATES expected here" */
#define CE_RETRIEVE_OPT     1528    /* MSG "STATUS, HIGH, KEY, or SUB-INDEX expected here" */
#define CE_EXP_LOC_GLOB     1529    /* MSG "LOCAL or GLOBAL expected here" */
#define CE_CHANNEL_LIT      1530    /* MSG "This must be an unsigned integer from 1 to 12" */
#define CE_BAD_MERIT        1531    /* MSG "This is not a valid merit value" */
#define CE_KEY_ALT_CONF     1532    /* MSG "A file cannot have multiple RECORD keys and ALTERNATE keys" */
#define CE_MAX_VOLS         1533    /* MSG "Too many volumes have been defined" */
#define CE_510              1534
#define CE_EOP_SEQ_LIN      1535    /* MSG "[NOT] END-OF-PAGE can only be used with a file with LINAGE" */
#define CE_BAD_OPND         1536    /* MSG "This item is not an appropriate class, type, or usage for this context" */
#define CE_NOT_SUBINDEX     1537    /* MSG "The file does not allow sub-indexes" */
#define CE_514              1538
#define CE_MAX_OPNDS        1539    /* MSG "The compiler limit for number of operands / arguments has been exceeded" */
#define CE_CHAN_NO_LINES    1540    /* MSG "This item does not specify a channel name" */
#define CE_CONFL_LINAGE     1541    /* MSG "This option may not be used for a file with LINAGE" */
#define CE_ILL_MOTION       1542    /* MSG "Invalid motion option" */
#define CE_519              1543
#define CE_INS_PAR_NAME     1544    /* MSG "Section was not followed by a paragraph name; a dummy name was inserted" */
#define CE_VAL_IS_ARE       1545    /* MSG "Incorrect usage in value clause: VALUE ARE or VALUES IS" */
#define CE_EXTERN_01_77     1546    /* MSG "EXTERNAL may only be specified for 01 or 77 level items" */
#define CE_EXTERN_WS        1547    /* MSG "EXTERNAL may only be used for data items in WORKING-STORAGE" */
#define CE_EXTERN_REDEF     1548    /* MSG "EXTERNAL may not be used along with REDEFINES" */
#define CE_REQ_EXTERN       1549    /* MSG "This item should have the EXTERNAL attribute" */
#define CE_EXTERN_SAME      1550    /* MSG "An EXTERNAL file may not be specified in the SAME ... AREA clause" */
#define CE_BAD_RECLEN       1551    /* MSG "This item is not a valid record length item" */
#define CE_INV_SM_ORG       1552    /* MSG "The clause/statement is not valid for a SORT/MERGE file" */
#define CE_INV_INFOS_ORG    1553    /* MSG "The clause/statement is not valid for an INFOS INDEXED file" */
#define CE_NEED_INFOS       1554    /* MSG "The file must be an INFOS INDEXED file" */
#define CE_INV_PRIM_KEY     1555    /* MSG "Invalid primary key definition for an ANSI INDEXED file" */
#define CE_ISAM_IGN_IT      1556    /* MSG "ASSIGN DATA and all but first ASSIGN INDEX are ignored for an ANSI INDEXED file" */
#define CE_533              1557
#define CE_INV_NUM          1558    /* MSG "The non-numeric literal does not contain a valid numeric value" */
#define CE_LINAGE_FILE      1559    /* MSG "LINAGE-COUNTER is not valid for this file" */
#define CE_LINAGE_NONE      1560    /* MSG "LINAGE-COUNTER is not valid for any files in this program" */
#define CE_537              1561
#define CE_MAX_EXT_SIZE     1562    /* MSG "The Maximum size of an EXTERNAL item is limited to 1 MB" */
#define CE_MAX_EXT_CNT      1563    /* MSG "The total number of files, USING items, and EXTERNAL items is limited to 1024" */
#define CE_TRUNC_ID_CX      1564    /* MSG "The identifier was truncated to 30 characters in the code file" */
#define CE_ILL_MOVE_SPC     1565    /* MSG "Illegal MOVE SPACES to numeric, numeric-edited or index item; using MOVE 0 instead" */
#define CE_UNEXP_SEC        1566    /* MSG "The PROCEDURE DIVISION must start with a section in order to use sections" */
#define CE_MOVE_NOT_STD     1567    /* MSG "This MOVE construct behaves differently from ANSI COBOL" */
#define CE_UFOS_LIMIT       1568    /* MSG "This item exceeds limits supported by U/FOS" */
#define CE_UFOS_SUPPORT     1569    /* MSG "U/FOS ignores this feature" */
#define CE_INDEX_LEVELS     1570    /* MSG "The number of sub-index levels is too large" */
#define CE_DEP_ON_CNT       1571    /* MSG "The maximum number of GO TO ... DEPENDING operands has been exceeded" */
#define CE_PRIMARY_ONLY     1572    /* MSG "Only the primary key may be used in the KEY IS clause for an ANSI INDEXED file" */
#define CE_LOGICAL_LOCAL    1573    /* MSG "LOGICAL LOCAL is not implemented for ANSI INDEXED files" */
#define CE_KEY_OUTSIDE      1574    /* MSG "This key falls entirely or partially outside of a minimum or maximum length record" */
#define CE_REC_MIN_INC      1575    /* MSG "Minimum record size has been increased enough to contain this key" */
#define CE_KEYLEN_MATCH     1576    /* MSG "The length of this key does not match the KEY LENGTH specified" */
#define CE_IMPLY_PRINTER    1577    /* MSG "ASSIGN TO PRINTER is implied for this file due to the LINAGE clause" */
#define CE_START_SEQ        1578    /* MSG "Record number is not allowed on sequential START for DATA-SENSITIVE or VARIABLE files" */
#define CE_SM_KEY_IN_REC    1579    /* MSG "The first RECORD KEY for this file is not within any of the file's records" */
#define CE_ZERO_LEN_LIT     1580    /* MSG "Standard COBOL does not allow this construct; it is being treated as a single space" */
#define CE_FILE_SEC_ITEM    1581    /* MSG "This item should not be defined in the FILE SECTION" */
#define CE_SEGMENT_COUNT    1582    /* MSG "Too many key suffixes have been specified" */
#define CE_ALSO_COUNT       1583    /* MSG "Too many keys have been specified in the ALSO clause" */
#define CE_KEY_QUAL         1584    /* MSG "A composite key name may not be qualified" */
#define CE_DUPL_KEY_DESC    1585    /* MSG "Duplicate or conflicting options in the RECORD KEY or ALTERNATE KEY clause" */
#define CE_INV_KEY_OPT      1586    /* MSG "This option is not valid for the RECORD KEY" */
#define CE_SUPPRESS_LIT     1587    /* MSG "The suppress literal must be a single character" */
#define CE_KEY_OCC_CNT      1588    /* MSG "The OCCURS count in the ALTERNATE KEY clause must be between 1 and 31" */
#define CE_ALSO_LEN         1589    /* MSG "Each key in the ALSO clause must have the same length as the root key" */
#define CE_SEG_OVERLAP      1590    /* MSG "This key suffix overlaps with the root key or another key suffix" */
#define CE_ALSO_OVERLAP     1591    /* MSG "This ALSO key overlaps with the root key or another ALSO key" */
#define CE_KEY_OCC_DIFF     1592    /* MSG "The OCCURS count in the ALTERNATE KEY clause must match that of the key data item" */
#define CE_KEY_OCC_DAD      1593    /* MSG "This key suffix is subordinate to an OCCURS entry different from that of the root key" */
#define CE_KEY_OCC_NONE     1594    /* MSG "The root key and each key suffix must be subordinate to an OCCURS entry" */
#define CE_SM_KEY_DESC      1595    /* MSG "An output file is indexed with a descending primary key, so this key must be descending" */
#define CE_SM_SEGMENTED     1596    /* MSG "The primary key of an INDEXED file specified in the GIVING clause may not be suffixed" */
#define CE_KEY_OCCURS       1597    /* MSG "This key, key suffix or ALSO key may not be subordinate to an item with an OCCURS clause" */
#define CE_NOT_VARYING      1598    /* MSG "The RECORD DELIMITER clause requires a file whose record IS VARYING IN SIZE" */
#define CE_REQ_DEP_NAME     1599    /* MSG "A DEPENDING ON name must be specified with explicit or implicit RECORD DELIMITER IS SIZE" */
#define CE_BAD_DELIM_INTO   1600    /* MSG "This item is not a valid DELIMITER INTO data-item" */
#define CE_577              1601
#define CE_578              1602
#define CE_PIC_W_PTR        1603    /* MSG "The PICTURE clause may not be specified with USAGE POINTER" */
#define CE_SIGN_W_PTR       1604    /* MSG "The SIGN clause may not be specified with USAGE POINTER" */
#define CE_JUST_W_PTR       1605    /* MSG "The JUSTIFIED clause may not be specified with USAGE POINTER" */
#define CE_B_Z_W_PTR        1606    /* MSG "The BLANK WHEN ZERO clause may not be specified with USAGE POINTER" */
#define CE_HEX_LIT_LEN      1607    /* MSG "Numeric hexadecimal literal is too long" */
#define CE_SYNC_W_PTR       1608    /* MSG "The SYNCHRONIZED clause may not be specified with USAGE POINTER" */
#define CE_INV_USE_PTR      1609    /* MSG "This is an invalid use of a data item with USAGE POINTER" */
#define CE_NO_XEQ_BIG       1610    /* MSG "This program cannot execute on a big endian machine" */
#define CE_NO_XEQ_LITTLE    1611    /* MSG "This program cannot execute on a little endian machine" */
#define CE_BAD_HEX_LIT      1612    /* MSG "Invalid hexadecimal literal or improper continuation" */
#define CE_INS_SEC_NAME     1613    /* MSG "Procedure Division did not begin with a section name; a dummy name was inserted" */
#define CE_INFOS_LIMIT      1614    /* MSG "This item exceeds the limits supported by INFOS II" */
#define CE_ERROR_LIMIT      1615    /* MSG "The maximum error limit has been reached" */
#define CE_STMT_INVALID     1616    /* MSG "A previous error has invalidated this statement; correct the errors and try again" */
#define CE_INFOS_UNSUPP     1617    /* MSG "INFOS features are no longer supported at run time (as of 5.30) */
#define CE_594              1618
#define CE_IGN_UNEXP        1619    /* MSG "The unexpected token is being ignored" */
#define CE_BAD_NUMBER       1620    /* MSG "The numeric literal has comma or period that is not the decimal point" */
#define CE_597              1621
#define CE_EXP_QUAL_ITEM    1622    /* MSG "Another qualifying name is expected here" */
#define CE_CLOSE_PAREN      1623    /* MSG "There are one or more missing closing parentheses" */
#define CE_CLOSE_PSEUDO     1624    /* MSG "The closing '==' pseudo-text delimiter is missing" */
#define CE_EMPTY_PSEUDO     1625    /* MSG "The pseudo-text specifier to the left of BY cannot be empty" */
#define CE_EXP_REPL         1626    /* MSG "REPLACING operands are expected here" */
#define CE_NO_DEBUGGING     1627    /* MSG "DEBUGGING MODE is controlled from the command line and is not on" */
#define CE_UNRECOV_STOP     1628    /* MSG "Compilation cannot proceed because of errors found so far" */
#define CE_BEF_QUOTE        1629    /* MSG "A space or left parenthesis is required before the opening quote; a space was inserted" */
#define CE_PIC_W_INT_FP     1630    /* MSG "The PICTURE clause may not be specified with USAGE COMP1 or COMP2" */
#define CE_SIGN_W_INT_FP    1631    /* MSG "The SIGN clause may not be specified with USAGE COMP1 or COMP2" */
#define CE_JUST_W_INT_FP    1632    /* MSG "The JUSTIFIED clause may not be specified with USAGE COMP1 or COMP2" */
#define CE_B_Z_W_INT_FP     1633    /* MSG "The BLANK WHEN ZERO clause may not be specified with USAGE COMP1 or COMP2" */
#define CE_FP_PREC_NUM      1634    /* MSG "The maximum total precision allowed in the mantissa of a floating point literal is 16 digits" */
#define CE_FP_PREC_EXP      1635    /* MSG "The maximum precision allowed in the exponent of a floating point literal is 2 digits" */
#define CE_FP_PREC_PIC      1636    /* MSG "The maximum total precision allowed in the mantissa is 16 digits" */
#define CE_INV_FP_PIC       1637    /* MSG "This is not a valid floating point picture-string" */
#define CE_FP_LIT_RANGE     1638    /* MSG "This floating point constant is outside the range of supported values" */
#define CE_ILL_LABEL        1639    /* MSG "The LABEL RECORD format specified is not valid for this type of file" */
#define CE_LABEL_LEVEL      1640    /* MSG "The tape level specified is out of range for this LABEL RECORD format" */
#define CE_MAX_LABEL_CNT    1641    /* MSG "Too many USER VOLUME, USER HEADER or USER TRAILER labels have been specified" */
#define CE_LABEL_PRINTER    1642    /* MSG "The LABEL RECORDS format conflicts with ASSIGN TO PRINTER" */
#define CE_DUPL_PARA        1643    /* MSG "This optional paragraph has already been specified" */
#define CE_REQ_DEVICE       1644    /* MSG "A device specifier must preceed a data-name used in the ASSIGN clause" */
#define CE_FLD_IN_REC       1645    /* MSG "This CODE-SET field is not in a record description for this file" */
#define CE_FLD_DIFF_REC     1646    /* MSG "All CODE-SET fields must be within the same record description" */
#define CE_FLD_OVERLAP      1647    /* MSG "This CODE-SET field overlaps with another CODE-SET field" */
#define CE_INV_ALPHABET     1648    /* MSG "The CODE-SET may not reference a user-defined alphabet" */
#define CE_EXP_ADVANCING    1649    /* MSG "The keyword ADVANCING is expected here" */
#define CE_SUBST_INV_KEY    1650    /* MSG "An INVALID KEY clause in being substituted for the AT END clause" */
#define CE_V6_ISAM_LIMIT    1651    /* MSG "This item is unsupported or exceeds the limits of IC_ISAM Version 6 files." */
#define CE_ADV_REQ_PRINT    1652    /* MSG "The ADVANCING phrase may only be specified with PRINTER files" */
#define CE_EXP_FUNC_NAME    1653    /* MSG "A function name is expected here" */
#define CE_UNREC_FUNC       1654    /* MSG "The specified function name is not a supported function" */
#define CE_TOO_MANY_ARGS    1655    /* MSG "Too many arguments were supplied for the function" */
#define CE_TOO_FEW_ARGS     1656    /* MSG "Too few arguments were supplied for the function" */
#define CE_INT_EXPR         1657    /* MSG "An integer literal, identifier, or arithmetic expression is expected here" */
#define CE_NEST_REFMOD      1658    /* MSG "An item cannot be reference modified more than once" */
#define CE_BAD_PRINT_Q      1659    /* MSG "This item is not a valid printer queue item" */
#define CE_SM_USG_MODE      1660    /* MSG "This file may not be a USING file due to its RECORD DELIMTER or RECORDING MODE" */
#define CE_EVAL_LIMIT       1661    /* MSG "The number of EVALUATE subjects or objects exceeds the compiler's limit" */
#define CE_EVAL_FEW         1662    /* MSG "There are fewer EVALUATE objects than subjects" */
#define CE_EVAL_MANY        1663    /* MSG "There are more EVALUATE objects than subjects" */
#define CE_640              1664
#define CE_EVAL_THRU        1665    /* MSG "Both items in the THRU clause must be of the same class" */
#define CE_THRU_NO_COND     1666    /* MSG "conditional expression cannot be used with THRU" */
#define CE_PIC_LEN_ANSI     1667    /* MSG "The length of the PICTURE string exceeds the ANSI limit of 30 characters" */
#define CE_CLS_AB_AN        1668    /* MSG "The item must be class alphabetic or alphanumeric" */
#define CE_INCONS_ARG       1669    /* MSG "This item is not consistent with preceding items in the agument list" */
#define CE_UNSUPP_ARG       1670    /* MSG "An item of this type is not supported as an argument to this function" */
#define CE_NO_REFMOD        1671    /* MSG "This item may not be reference modified" */
#define CE_MAX_FILES        1672    /* MSG "The maximum number of allowable files has been exceeded" */
#define CE_EXP_REPL_DEF     1673    /* MSG "The REPLACING or DEFAULT phrase is expected here" */
#define CE_INV_USE_REN      1674    /* MSG "This is an invalid use of a data item with RENAMES" */
#define CE_NO_INIT          1675    /* MSG "This item has no applicable initialization phrase; it will not be initialized" */
#define CE_MAX_CONDS        1676    /* MSG "The maximum number of condition names for an item has been reached" */
#define CE_NOT_SUPPORTED    1677    /* MSG "This option is not supported" */
#define CE_TOO_MANY_CORR    1678    /* MSG "Too many items correspond" */
#define CE_COND_INX_PTR     1679    /* MSG "A condition name may not be defined for INDEX, POINTER, or INDICATOR data-items" */
#define CE_EXTERN_W_PTR     1680    /* MSG "The EXTERNAL clause may not be specified with USAGE POINTER" */
#define CE_ACCEPT_WIDTH     1681    /* MSG "The size of this identifier exceeds the maximum for a data item ACCEPT" */
#define CE_EXTEND_LINAGE    1682    /* MSG "OPEN EXTEND may not be specified for a file with the LINAGE clause" */
#define CE_INCONS_SRC       1683    /* MSG "A file was modified during the course of compilation - restart compilation" */
#define CE_COMP_NOT_IN_PROJ 1684    /* MSG "The current file cannot be compiled: it is not in the project or not a source file" */
#define CE_ERASE_END_OPT    1685    /* MSG "LINE or SCREEN is expected here" */
#define CE_LC_MINUS_VAL     1686    /* MSG "The LINE MINUS or COLUMN MINUS value must be from 0 to 255" */
#define CE_LC_UNDERFLOW     1687    /* MSG "The computed starting line or column position is less than one" */
#define CE_SCRN_TBL_DIM     1688    /* MSG "The data item and screen tables differ in the number of dimensions" */
#define CE_SCRN_TBL_CNT     1689    /* MSG "The data item and screen tables differ in the number of occurrences" */
#define CE_SCRN_TBL_DEP     1690    /* MSG "This item may not be subordinate to an OCCURS ... DEPENDING" */
#define CE_SCRN_TBL_LIT     1691    /* MSG "This item must be a part of a table; it may not be a literal" */
#define CE_REQ_REL_POS      1692    /* MSG "The OCCURS clause requires that either the LINE or COLUMN clause include the PLUS or MINUS phrase" */
#define CE_MOVE_TRUNC       1693    /* MSG "This source operand may be truncated by the MOVE" */
#define CE_MNEM_DATA        1694    /* MSG "Mnemonic-name is not allowed when screen control is present on any data-item operands" */
#define CE_NOT_W_CTRL       1695    /* MSG "This clause may not be specified when screen control is present on any data-item operands" */
#define CE_1_SCRN_DATA      1696    /* MSG "Only one screen-name or data-name may be specified in this type of ACCEPT statement" */
#define CE_EXP_SUBQUERY     1697    /* MSG "A subquery is expected here" */
#define CE_674              1698
#define CE_675              1699
#define CE_EXP_ALIAS        1700    /* MSG "An alias name is expected here" */
#define CE_677              1701
#define CE_EXP_SQL_TABLE    1702    /* MSG "A SQL table-name is expected here" */
#define CE_EXP_SQL_COL      1703    /* MSG "A SQL column-name is expected here" */
#define CE_EXP_SET_CLAUSE   1704    /* MSG "The SET clause is expected here" */
#define CE_EXP_SQL_NAME     1705    /* MSG "A valid SQL name is expected here" */
#define CE_EXP_TBL_IND      1706    /* MSG "TABLE or INDEX is expected here" */
#define CE_EXP_CREATECOLS   1707    /* MSG "A list of column definitions is expected here" */
#define CE_EXP_INDEXCOLS    1708    /* MSG "A list of columns to index on is expected here" */
#define CE_EXP_DATATYPE     1709    /* MSG "An SQL data type is expected here" */
#define CE_EXP_PREC         1710    /* MSG "A precision specification is expected here" */
#define CE_EXP_INTERVAL     1711    /* MSG "The start or end of an interval is expected here" */
#define CE_INT_GE_0         1712    /* MSG "The integer must be greater than or equal to 0" */
#define CE_INV_USE_IND      1713    /* MSG "This is an invalid use of an indicator data item" */
#define CE_SIZE_LIMIT       1714    /* MSG "This item exceeds the size allowed by the compiler" */
#define CE_SCALE_LE_PREC    1715    /* MSG "The scale must be less than or equal to the precision" */
#define CE_PIC_W_SQL        1716    /* MSG "The PICTURE clause cannot be used with an SQL usage" */
#define CE_SIGN_W_SQL       1717    /* MSG "The SIGN clause may not be specified with an SQL usage" */
#define CE_JUST_W_SQL       1718    /* MSG "The JUSTIFIED clause may not be specified with an SQL usage" */
#define CE_B_Z_W_SQL        1719    /* MSG "The BLANK WHEN ZERO clause may not be specified with an SQL usage" */
#define CE_SYNC_W_SQL       1720    /* MSG "The SYNCHRONIZED clause may not be specified with an SQL usage" */
#define CE_INV_DATE         1721    /* MSG "This is not a valid DATE literal" */
#define CE_INV_TIME         1722    /* MSG "This is not a valid TIME literal" */
#define CE_INV_TIMESTAMP    1723    /* MSG "This is not a valid TIMESTAMP literal" */
#define CE_INV_INTERVAL     1724    /* MSG "This is not a valid INTERVAL literal" */
#define CE_VALUE_LEFT       1725    /* MSG "The value exceeds the item in the leftmost field" */
#define CE_VALUE_RIGHT      1726    /* MSG "The value exceeds the item in the rightmost field" */
#define CE_VALUE_BOTH       1727    /* MSG "The value exceeds the item in both leftmost and rightmost fields" */
#define CE_SQL_TO_FR_USG    1728    /* MSG "SQL usage requires TO, FROM, or USING" */
#define CE_INV_NULLSTR      1729    /* MSG "An empty non-numeric literal is not valid here" */
#define CE_NOT_INDICATOR    1730    /* MSG "This is not an indicator data item" */
#define CE_NUM_DTI_ID_LIT   1731    /* MSG "A numeric, date-time, or interval identifier or literal is required" */
#define CE_NUM_DTI_OPND     1732    /* MSG "A numeric, date-time, or interval id-lit or expression is expected here" */
#define CE_NUM_I_ID_LIT     1733    /* MSG "A numeric or interval identifier or literal is required" */
#define CE_NUM_I_OPND       1734    /* MSG "A numeric or interval id-lit or expression is expected here" */
#define CE_NUM_DT_ID_LIT    1735    /* MSG "A numeric or date-time identifier or literal is required" */
#define CE_NUM_DT_OPND      1736    /* MSG "A numeric or date-time id-lit or expression is expected here" */
#define CE_ILL_EXPR         1737    /* MSG "Illegal combination of numeric, interval and date-time operands in expression" */
#define CE_ONE_CHR_VAL      1738    /* MSG "This item must contain just a single character" */
#define CE_INS_VAR_LEN      1739    /* MSG "The lengths of the two operands in the BY or TO clause must be equal at execution time" */
#define CE_NOT_DISP_SQL     1740    /* MSG "The item is not USAGE DISPLAY or CHARACTER [VARYING]" */
#define CE_NO_VAR_LEN       1741    /* MSG "This item may not be variable length" */
#define CE_ID_LIT_30        1742    /* MSG "The id-lit value may not exceed 30 characters in length" */
#define CE_SQLSTATE         1743    /* MSG "This is not a valid use of SQLSTATE" */
#define CE_INT_NE_0         1744    /* MSG "The integer value may not be zero" */
#define CE_EXP_TEXT_LEN     1745    /* MSG "TEXT or LENGTH is expected here" */
#define CE_EXP_GET_EXC      1746    /* MSG "An DIAGNOSTICS EXCEPTION selector phrase is expected here" */
#define CE_EXP_GET_HDR      1747    /* MSG "A DIAGNOSTICS header selector phrase is expected here" */
#define CE_ID_LIT_EXPR      1748    /* MSG "An identifier, literal, or arithmetic expression is expected here" */
#define CE_EXP_FUNC_ARG     1749    /* MSG "A function argument is expected here" */
#define CE_EXP_GET_KWDS     1750    /* MSG "COLUMNS, DIAGNOSTICS, or TABLES is expected here" */

/* BLANK 297 */

#define CE_MAX_ERROR        2047    /* maximum allowable cobol error number */

