* PQ_LIST.WS - PQ File List interface
*
*    Copyright (C) 2000 Envyr Corporation, All Rights Reserved.
*
*    Revision History:
*       07/13/00 JMB ic3.00     New
*       08/20/00 JMB ic3.01     Added info operation to IC_QUEUE_OPERATION
*

***********************************************************************
* Declarations for use with the IC_QUEUE_LIST and IC_QUEUE_OPERATION  *
* builtin functions.  NOTE:  IC_QUEUE_LIST uses the IC-QUEUE-LIST-PKT *
* and IC_QUEUE_OPERATION uses any occurrence of IC-QUEUE-LIST-ENTRY.  *
***********************************************************************

******************************************************************************
*         Key to structure contents:  IC-QUEUE-LIST-PKT                      *
******************************************************************************
*                                                                            *
* Notes: (1) On a call to IC_QUEUE_LIST, the packet revision must be set to  *
*            one.  No other field needs to be set, and if set it will be     *
*            overwritten.                                                    *
*                                                                            *
*        (2) On a call to IC_QUEUE_OPERATION all fields should be left       *
*            exactly as returned from a call to IC_QUEUE_LIST.  The only     *
*            exception is that certain fields -- as noted below -- may be    *
*            set with the new values requested on a modify operation.        *
*                                                                            *
******************************************************************************
*                                                                            *
* IC-QUEUE-LIST-PKT-REV                                                      *
*       Revision of this packet structure -- it must always be set to 1.     *
* IC-QUEUE-OS-TYPE                                                           *
*       Operating system on which call is executed (returned by call).       *
*       Windows = 1, UNIX = 2                                                *
* IC-QUEUE-LIST-COUNT                                                        *
*       Number of entries returned from call                                 *
* IC-QUEUE-LIST-ENTRY                                                        *
*       Array of queue entries.  The maximum size may be lowered from 1024   *
*       to a smaller number, but MUST be a least as large as the configured  *
*       number of printer control entries.                                   *
* IC-QUEUE-LIST-FILE-SIZE                                                    *
*       Size of the file to be printed.                                      *
* IC-QUEUE-LIST-PRINT-ERR-CODE                                               *
*       Standard ICOBOL exception code.  Corresponding text can be retrieved *
*       for it using the IC_MSG_TXT builtin function.  This code is valid    *
*       when IC-QUEUE-LIST-STATUS is IC-QUEUE-LIST-STATUS-ERROR or           *
*       IC-QUEUE-LIST-STATUS-RETRY.                                          *
* IC-QUEUE-LIST-OWNER-USER-ID                                                *
*       User id number (UNIX) or console number (WINDOWS) of the file's      *
*       If not yet known or assigned the field will contain NULL-USER-ID.    *
* IC-QUEUE-LIST-PRINT-USER-ID                                                *
*       User id number (UNIX) or console number (WINDOWS) of the last user   *
*       who printed the file.  If not yet know or assigned the field will    *
*       contain NULL-USER-ID.                                                *
* IC-QUEUE-LIST-TIME-MODIFIED                                                *
*       The time the file was last modified returned as a string of the form *
*       mmm-dd-yyyy hh:mm:ss.hh                                              *
* IC-QUEUE-LIST-TIME-PRINTED                                                 *
*       The time the file was last printed returned as a string of the form  *
*       mmm-dd-yyyy hh:mm:ss.hh                                              *
* IC-QUEUE-LIST-OWNER-USER-NAME                                              *
*       User name of the file's owner                                        *
* IC-QUEUE-LIST-PRINT-USER-NAME                                              *
*       User name of the last user who printed the file                      *
* IC-QUEUE-LIST-FIRST-PAGE                                                   *
*       First page to print.  (May be set for modify operation.)  If this    *
*       value is NULL-PAGE-NUMBER all pages will be printed.                 *
* IC-QUEUE-LIST-LAST-PAGE                                                    *
*       Last page to print.  (May be set for modify operation.)  If this     *
*       value is NULL-PAGE-NUMBER all from the specified first through the   *
*       end of the file will be printed.  If IC-QUEUE-LIST-FIRST-PAGE is     *
*       NULL-PAGE-NUMBER, the IC-QUEUE-LIST-LAST-PAGE should be as well.     *
* IC-QUEUE-LIST-PCQ-UNIT                                                     *
*       PCQ unit on which the file is assigned to print.  (May be set for    *
*       modify operation.)  It should always be less than the maximum        *
*       configured PCQ.                                                      *
* IC-QUEUE-LIST-PRIORITY                                                     *
*       Print job's priority.  (May be set for modify operation.)            *
*       Normally this is set to NULL-PRIORITY to allow the system to assign. *
*       Note that UNIX and Windows priorities differ (see below).            *
* IC-QUEUE-LIST-COPIES                                                       *
*       Number of copies to be printed.  (May be set for modify operation)   *
* IC-QUEUE-LIST-DISPOSITION                                                  *
*       Disposition of the printer queue entry when the file has finished    *
*       printing.  (It may be set for modify operation.)                     *
* IC-QUEUE-LIST-OPTION-NO-BANNER                                             *
*       (UNIX only) Suppress banner page when printing?  Field contains 'Y'  *
*       or 'N' for yes or no respectively.  (May be set for modify           *
*       operation.)                                                          *
* IC-QUEUE-LIST-OPTION-NOTIFY                                                *
*       (UNIX only) Notify when printing is complete?  Field contains 'Y' or *
*       'N' for yes or no respectively.  (May be set for modify operation.)  *
* IC-QUEUE-LIST-OPTION-START-FF                                              *
*       (Windows only) Start printing with a form-feed?  Field contains 'Y'  *
*       'N' for yes or no respectively.  (May be set for modify operation.)  *
* IC-QUEUE-LIST-OPTION-COPIES-FF                                             *
*       (Windows only) End each copy with a form-feed?  Field contains 'Y'   *
*       or 'N' for yes or no respectively.  (May be set for modify           *
*       operation.)                                                          *
* IC-QUEUE-LIST-OPTION-END-FF                                                *
*       (Windows only) End printing with a form-feed?  Field contains 'Y' or *
*       'N' for yes or no respectively.  (May be set for modify operation.)  *
* IC-QUEUE-LIST-STATUS                                                       *
*       This is a code for the current status of the print job.  (When any   *
*       operation is performed, the status is cross-checked against the      *
*       operation for validity.)  Certain information in this packet is      *
*       only valid when a print job has a particular status.                 *
* IC-QUEUE-LIST-WIN-PRINT-COPY                                               *
*       (Windows only) Copy number currently being printed.  This number is  *
*       only valid when IC-QUEUE-LIST-STATUS is IC-QUEUE-LIST-STATUS-PRINT.  *
* IC-QUEUE-LIST-WIN-PRINT-PCNT                                               *
*       (Windows only) Percentage of job already printed.  This number is    *
*       only valid when IC-QUEUE-LIST-STATUS is IC-QUEUE-LIST-STATUS-PRINT.  *
* IC-QUEUE-LIST-UNIX-REQ-ID-LEN                                              *
*       (UNIX only) Length of the lp request id.  This number is only valid  *
*       when IC-QUEUE-LIST-STATUS is IC-QUEUE-LIST-STATUS-QUEUE,             *
*       IC-QUEUE-LIST-STATUS-HOLD, IC-QUEUE-LIST-STATUS-PRINT or             *
*       IC-QUEUE-LIST-STATUS-TERM.                                           *
* IC-QUEUE-LIST-UNIX-REQ-ID                                                  *
*       (UNIX only) The lp request id.  This field is only valid when        *
*       IC-QUEUE-LIST-STATUS is IC-QUEUE-LIST-STATUS-QUEUE,                  *
*       IC-QUEUE-LIST-STATUS-HOLD, IC-QUEUE-LIST-STATUS-PRINT or             *
*       IC-QUEUE-LIST-STATUS-TERM.                                           *
* IC-QUEUE-LIST-QUEUE-SPOT                                                   *
*       Print job's current ordinal spot in the queue.  This field is only   *
*       valid when IC-QUEUE-LIST-STATUS is IC-QUEUE-LIST-STATUS-QUEUE or     *
*       IC-QUEUE-LIST-STATUS-HOLD.                                           *
* IC-QUEUE-LIST-FILE-NAME-LEN                                                *
*       Length of the pathname found in IC-QUEUE-LIST-FILE-NAME.             *
* IC-QUEUE-LIST-SIMPLE-NAME-OFS                                              *
*       One-based offset to simple filename found in IC-QUEUE-LIST-FILE-NAME *
* IC-QUEUE-LIST-FILE-NAME                                                    *
*       Full pathname of the file to be printed                              *
*                                                                            *
******************************************************************************

01 IC-QUEUE-LIST-PKT.
   05 IC-QUEUE-LIST-PKT-REV                     PIC 9(2) COMP VALUE 1.
   05 IC-QUEUE-LIST-OS-TYPE                     PIC 9(2) COMP.
      88 IC-QUEUE-LIST-OS-TYPE-WINDOWS VALUE 1.
      88 IC-QUEUE-LIST-OS-TYPE-UNIX    VALUE 2.
   05 IC-QUEUE-LIST-COUNT                       PIC 9(4) COMP.
   05 IC-QUEUE-LIST-ENTRY OCCURS 1 TO 1024 TIMES
                          DEPENDING ON IC-QUEUE-LIST-COUNT.
      10 IC-QUEUE-LIST-FILE-SIZE                PIC 9(9) COMP.
      10 IC-QUEUE-LIST-PRINT-ERR-CODE           PIC 9(9) COMP.
      10 IC-QUEUE-LIST-OWNER-USER-ID            PIC 9(9) COMP.
      10 IC-QUEUE-LIST-PRINT-USER-ID            PIC 9(9) COMP.
      10 IC-QUEUE-LIST-TIME-MODIFIED            PIC X(24).
      10 IC-QUEUE-LIST-TIME-PRINTED             PIC X(24).
      10 IC-QUEUE-LIST-OWNER-USER-NAME          PIC X(16).
      10 IC-QUEUE-LIST-PRINT-USER-NAME          PIC X(16).
      10 IC-QUEUE-LIST-FIRST-PAGE               PIC 9(9) COMP.
      10 IC-QUEUE-LIST-LAST-PAGE                PIC 9(9) COMP.
      10 IC-QUEUE-LIST-PCQ-UNIT                 PIC 9(4) COMP.
      10 IC-QUEUE-LIST-PRIORITY                 PIC 9(4) COMP.
      10 IC-QUEUE-LIST-COPIES                   PIC 9(4) COMP.
      10 IC-QUEUE-LIST-DISPOSITION              PIC 9(2) COMP.
      10 IC-QUEUE-LIST-OPTIONS.
         15 IC-QUEUE-LIST-OPTION-NO-BANNER      PIC X.
         15 IC-QUEUE-LIST-OPTION-NOTIFY         PIC X.
         15 IC-QUEUE-LIST-OPTION-START-FF       PIC X.
         15 IC-QUEUE-LIST-OPTION-COPIES-FF      PIC X.
         15 IC-QUEUE-LIST-OPTION-END-FF         PIC X.
         15 FILLER                              PIC X(11).
      10 IC-QUEUE-LIST-STATUS                   PIC 9(2) COMP.
      10 IC-QUEUE-LIST-OS-INFO                  PIC X(24).
      10 IC-QUEUE-LIST-WINDOWS REDEFINES IC-QUEUE-LIST-OS-INFO.
         15 IC-QUEUE-LIST-WIN-PRINT-COPY        PIC 9(4) COMP.
         15 IC-QUEUE-LIST-WIN-PRINT-PCNT        PIC 9(2) COMP.
         15 FILLER                              PIC X(21).
      10 IC-QUEUE-LIST-UNIX REDEFINES IC-QUEUE-LIST-OS-INFO.
         15 IC-QUEUE-LIST-UNIX-REQ-ID-LEN       PIC 9(4) COMP.
         15 IC-QUEUE-LIST-UNIX-REQ-ID           PIC X(22).
      10 IC-QUEUE-LIST-QUEUE-SPOT               PIC 9(4) COMP.
      10 IC-QUEUE-LIST-FILE-NAME-LEN            PIC 9(4) COMP.
      10 IC-QUEUE-LIST-SIMPLE-NAME-OFS          PIC 9(4) COMP.
      10 FILLER                                 PIC X(2).
      10 IC-QUEUE-LIST-FILE-NAME                PIC X(256).


* Flag values for unassigned entries
01 NULL-PAGE-NUMBER                             PIC 9(9) COMP VALUE 4294967295.
01 NULL-USER-ID                                 PIC 9(9) COMP VALUE 4294967295.
01 NULL-PRIORITY                                PIC 9(4) COMP VALUE 65535.

* Priority values
01 UNIX-HIGH-PRIORITY                           PIC 9(4) COMP VALUE 0.
01 UNIX-LOW-PRIORITY                            PIC 9(4) COMP VALUE 39.
01 UNIX-DEFAULT-PRIORITY                        PIC 9(4) COMP VALUE 39.
01 WINDOWS-HIGH-PRIORITY                        PIC 9(4) COMP VALUE 99.
01 WINDOWS-LOW-PRIORITY                         PIC 9(4) COMP VALUE 1.
01 WINDOWS-DEFAULT-PRIORITY                     PIC 9(4) COMP VALUE 1.


*  Values for IC-QUEUE-LIST-STATUS
01 FILLER.
*  No status
   03 IC-QUEUE-LIST-STATUS-NULL                 PIC 9(2) COMP VALUE ZERO.
*  Not yet printed
   03 IC-QUEUE-LIST-STATUS-NEW                  PIC 9(2) COMP VALUE 1.
*  Already printed
   03 IC-QUEUE-LIST-STATUS-OLD                  PIC 9(2) COMP VALUE 2.
*  Error has occurred
   03 IC-QUEUE-LIST-STATUS-ERROR                PIC 9(2) COMP VALUE 3.
*  Update in progress
   03 IC-QUEUE-LIST-STATUS-OPEN                 PIC 9(2) COMP VALUE 4.
*  Queued to print
   03 IC-QUEUE-LIST-STATUS-QUEUE                PIC 9(2) COMP VALUE 5.
*  Holding in the print queue
   03 IC-QUEUE-LIST-STATUS-HOLD                 PIC 9(2) COMP VALUE 6.
*  Printing
   03 IC-QUEUE-LIST-STATUS-PRINT                PIC 9(2) COMP VALUE 7.
*  Retrying due to error
   03 IC-QUEUE-LIST-STATUS-RETRY                PIC 9(2) COMP VALUE 8.
*  Terminating
   03 IC-QUEUE-LIST-STATUS-TERM                 PIC 9(2) COMP VALUE 9.


* Values for IC-QUEUE-LIST-DISPOSITION
01 FILLER.
*  Keep file (don't delete or remove)
   03 IC-QUEUE-LIST-KEEP-DISPOSITION            PIC 9(2) COMP VALUE ZERO.
*  Remove file from PASS after printing
   03 IC-QUEUE-LIST-REMOVE-DISPOSITI            PIC 9(2) COMP VALUE 1.
*  Delete file (and remove) after printing
   03 IC-QUEUE-LIST-DELETE-DISPOSITI            PIC 9(2) COMP VALUE 2.


*****************************************************
* Declarations for use with the IC_QUEUE_OPERATION  *
*****************************************************

01 IC-QUEUE-OPERATION-CODE                      PIC 9(2) COMP.

/* Values for IC-QUEUE-OPERATION-CODE */
01 IC-QUEUE-OPERATION-NULL                      PIC 9(2) COMP VALUE 0.
01 IC-QUEUE-OPERATION-CANCEL                    PIC 9(2) COMP VALUE 1.
01 IC-QUEUE-OPERATION-DELETE                    PIC 9(2) COMP VALUE 2.
01 IC-QUEUE-OPERATION-HOLD                      PIC 9(2) COMP VALUE 3.
01 IC-QUEUE-OPERATION-MODIFY                    PIC 9(2) COMP VALUE 4.
01 IC-QUEUE-OPERATION-PRINT                     PIC 9(2) COMP VALUE 5.
01 IC-QUEUE-OPERATION-REMOVE                    PIC 9(2) COMP VALUE 6.
01 IC-QUEUE-OPERATION-TERMINATE                 PIC 9(2) COMP VALUE 7.
01 IC-QUEUE-OPERATION-UNHOLD                    PIC 9(2) COMP VALUE 8.
01 IC-QUEUE-OPERATION-INFO                      PIC 9(2) COMP VALUE 9.
01 IC-QUEUE-OPERATION-FILTER                    PIC 9(2) COMP VALUE 10.

01 IC-QUEUE-OPERATION-COUNT                     PIC 9(2) COMP VALUE 11.


******************************************************************************
*          Key to structure contents: IC-QUEUE-OP-INFO-PKT                   *
******************************************************************************
*                                                                            *
* Notes: (1) On a call to IC_QUEUE_OPERATION with IC-QUEUE-OPERATION-CODE    *
*            set to IC-QUEUE-OPERATION-INFO, the packet revision must be set *
*            to one.  No other field needs to be set, and if set it will be  *
*            overwritten.                                                    *
*                                                                            *
******************************************************************************
*                                                                            *
* IC-QUEUE-OP-INFO-PKT-REV                                                   *
*       Revision of this packet structure -- it must always be set to 1.     *
* IC-QUEUE-OP-INFO-PCQ-COUNT                                                 *
*       This is the number of PCQ devices configured                         *
* IC-QUEUE-OP-INFO-PCQ-MAX-UNIT                                              *
*       This is the number of the highest PCQ device (currently 127)         *
* IC-QUEUE-OP-INFO-JOB-COUNT                                                 *
*       This is the configured maximum number of PCQ jobs                    *
******************************************************************************

01 IC-QUEUE-OP-INFO-PKT.
   05 IC-QUEUE-OP-INFO-PKT-REV                  PIC 9(2) COMP VALUE 1.
   05 FILLER                                    PIC X.
   05 IC-QUEUE-OP-INFO-PCQ-COUNT                PIC 9(4) COMP.
   05 IC-QUEUE-OP-INFO-PCQ-MAX                  PIC 9(4) COMP.
   05 IC-QUEUE-OP-INFO-JOB-COUNT                PIC 9(4) COMP.

******************************************************************************
*          Key to structure contents: IC-QUEUE-OP-FILT-PKT                   *
******************************************************************************
*                                                                            *
* Notes: (1) On a call to IC_QUEUE_OPERATION with IC-QUEUE-OPERATION-CODE    *
*            set to IC-QUEUE-OPERATION-FILTER, the packet revision must be   *
*            set to one.  No other field needs to be set, and if set it will *
*            be overwritten.                                                 *
*                                                                            *
******************************************************************************
*                                                                            *
* IC-QUEUE-OP-FILT-PKT-REV                                                   *
*       Revision of this packet structure -- it must always be set to 1.     *
* IC-QUEUE-OP-FILT-QUEUE                                                     *
*       If this field contains a 'Y', filtering by queue number is enabled.  *
*       The two fields IC-QUEUE-OP-FILT-MIN-PCQ and IC-QUEUE-OP-FILT-MIN-PCQ *
*       are valid and contain the minimum and maximum queues being viewed.   *
* IC-QUEUE-OP-FILT-SIZE                                                      *
*       If this field contains a 'Y', filtering by file size is enabled.     *
*       The fields IC-QUEUE-OP-FILT-MIN-SIZE and IC-QUEUE-OP-FILT-MIN-SIZE   *
*       are valid and contain the minimum and maximum file sizes being       *
*       viewed.                                                              *
* IC-QUEUE-OP-FILT-OWNER-ID                                                  *
*       If this field contains a 'Y', filtering by owner id is enabled.      *
*       (This is the console number on Windows and the user-id on UNIX.)     *
*       The two fields IC-QUEUE-OP-FILT-MIN-OWNER-ID and                     *
*       IC-QUEUE-OP-FILT-MAX-OWNER-ID are valid and contain the minimum and  *
*       maximum owner id value being viewed.                                 *
* IC-QUEUE-OP-FILT-PRINT-ID                                                  *
*       If this field contains a 'Y', filtering by printed-by id is enabled. *
*       (This is the console number on Windows and the user-id on UNIX.)     *
*       The two fields IC-QUEUE-OP-FILT-MIN-PRINT-ID and                     *
*       IC-QUEUE-OP-FILT-MAX-PRINT-ID are valid and contain the minimum and  *
*       maximum printed-by id value being viewed.                            *
* IC-QUEUE-OP-FILT-OWNER                                                     *
*       If this field contains a 'Y', filtering by owner name is enabled.    *
*       The field IC-QUEUE-OP-FILT-OWNER-NAME is valid and contains the      *
*       owner name of the files being viewed.                                *
* IC-QUEUE-OP-FILT-PRINT                                                     *
*       If this field contains a 'Y', filtering by printed-by name is        *
*       enabled.  The field IC-QUEUE-OP-FILT-PRINT-NAME is valid and         *
*       contains the printed-by name of the files being viewed.              *
* IC-QUEUE-OP-FILT-NAME                                                      *
*       If this field contains a 'Y', filtering by file name is enabled.     *
*       The field IC-QUEUE-OP-FILT-FILE-NAME is is valid and contains the    *
*       simple filename of the files being viewed.                           *
* IC-QUEUE-OP-FILT-ACCESS                                                    *
*       If this field contains a 'Y', filtering by read access to the file   *
*       is enabled.                                                          *
* IC-QUEUE-OP-FILT-STATUS                                                    *
*       If this field contains a 'Y', filtering by status is enabled.  The   *
*       field IC-QUEUE-OP-FILT-STATUS-VAL is valid and contains the status   *
*       value of the files being viewed.                                     *
* IC-QUEUE-OP-FILT-DIR                                                       *
*       If this field contains a 'Y', filtering by directory name is enabled.*
*       The field IC-QUEUE-OP-FILT-DIR-NAME is is valid and contains the     *
*       directory name of the files being viewed.                            *
* IC-QUEUE-OP-FILT-MIN-PCQ                                                   *
* IC-QUEUE-OP-FILT-MAX-PCQ                                                   *
*       If IC-QUEUE-OP-FILT-QUEUE contains a 'Y', these two fields are valid *
*       and contain the minimum and maximum queues being viewed.             *
* IC-QUEUE-OP-FILT-MIN-SIZE                                                  *
* IC-QUEUE-OP-FILT-MAX-SIZE                                                  *
*       If IC-QUEUE-OP-FILT-QUEUE contains a 'Y', these fields are valid and *
*       contain the minimum and maximum file sizes being viewed.             *
* IC-QUEUE-OP-FILT-MIN-OWNER-ID                                              *
* IC-QUEUE-OP-FILT-MAX-OWNER-ID                                              *
*       If IC-QUEUE-OP-OWNER-ID contains a 'Y', these fields are valid and   *
*       contain the minimum and maximum owner id value being viewed.         *
* IC-QUEUE-OP-FILT-MIN-PRINT-ID                                              *
* IC-QUEUE-OP-FILT-MAX-PRINT-ID                                              *
*       If IC-QUEUE-OP-PRINT-ID contains a 'Y', these fields are valid and   *
*       contain the minimum and maximum printed-by id value being viewed.    *
* IC-QUEUE-OP-FILT-STATUS                                                    *
*       If this field contains a 'Y', filtering by status is enabled.        *
* IC-QUEUE-OP-FILT-OWNER-NAME                                                *
*       If IC-QUEUE-OP-FILT-OWNER contains a 'Y', this field is valid and    *
*       contains the owner name of the files being viewed.                   *
* IC-QUEUE-OP-FILT-PRINT-NAME                                                *
*       If IC-QUEUE-OP-FILT-PRINT contains a 'Y', this field is valid and    *
*       contains the printed-by name of the files being viewed.              *
* IC-QUEUE-OP-FILT-FILE-NAME                                                 *
*       If IC-QUEUE-OP-FILT-NAME contains a 'Y', this field is valid and     *
*       contains the simple filename of the files being viewed.              *
* IC-QUEUE-OP-FILT-DIR-NAME                                                  *
*       If IC-QUEUE-OP-FILT-DIR contains a 'Y', this field is valid and      *
*       contains the directory name of the files being viewed.               *
*                                                                            *
******************************************************************************

01 IC-QUEUE-OP-FILT-PKT.
   05 IC-QUEUE-OP-FILT-PKT-REV                  PIC 9(2) COMP VALUE 1.
   05 FILLER                                    PIC X.
   05 IC-QUEUE-OP-FILT-OPTIONS.
      10 IC-QUEUE-OP-FILT-QUEUE                 PIC X.
      10 IC-QUEUE-OP-FILT-SIZE                  PIC X.
      10 IC-QUEUE-OP-FILT-OWNER-ID              PIC X.
      10 IC-QUEUE-OP-FILT-PRINT-ID              PIC X.
      10 IC-QUEUE-OP-FILT-OWNER                 PIC X.
      10 IC-QUEUE-OP-FILT-PRINT                 PIC X.
      10 IC-QUEUE-OP-FILT-NAME                  PIC X.
      10 IC-QUEUE-OP-FILT-ACCESS                PIC X.
      10 IC-QUEUE-OP-FILT-STATUS                PIC X.
      10 IC-QUEUE-OP-FILT-DIR                   PIC X.
      10 FILLER                                 PIC X(6).
   05 IC-QUEUE-OP-FILT-STATUS-VAL               PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MIN-PCQ                  PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MAX-PCQ                  PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MIN-OWNER-ID             PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MAX-OWNER-ID             PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MIN-PRINT-ID             PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MAX-PRINT-ID             PIC 9(4) COMP.
   05 IC-QUEUE-OP-FILT-MIN-SIZE                 PIC 9(8) COMP.
   05 IC-QUEUE-OP-FILT-MAX-SIZE                 PIC 9(8) COMP.
   05 IC-QUEUE-OP-FILT-OWNER-NAME               PIC X(16).
   05 IC-QUEUE-OP-FILT-PRINT-NAME               PIC X(16).
   05 IC-QUEUE-OP-FILT-FILE-NAME                PIC X(64).
   05 IC-QUEUE-OP-FILT-DIR-NAME                 PIC X(64).


