/*  bltnstub.c - Stub routine for adding user-defined routines

    Copyright (C) 1994, 2003, 2015 Envyr Corporation., All Rights Reserved.

*/


/* parameter files needed by user-defined subroutines */
#include <string.h>
#include <stdlib.h>

/* standard parameter files */
#include "osdefines.h"
#include "status_t.h"
#include "syserrs.h"
#include "calldefs.h"

#if ( OSISLINUX )
/* any Linux specific includes, definitions, etc.  */
#endif

#if ( OSISWINDOWS )
/* Any Windows specific includes, definitions, etc. */
#include <windows.h>
#endif

#if ( OSIS32BIT )
/* any 32-bit specific includes, definitions, etc.  */
#endif

#if ( OSIS64BIT )
/* any 64-bit specific includes, definitions, etc.  */
#endif


/*
    Step 1:  Define the routines

    At this point either insert the actual source code for the C routines
    that you wish to call or include a header file with their external
    declarations.

    Remember all routines have 2 arguments -- the first of argc_t
    representing the number of arguments to the function, and the
    second a pointer to a vector of type argv_t which contains the
    definitions of the actual arguments.  See the header file calldefs.h
    for more information of these.

    An example of a header file might be:

#include "sd_bltn.h"

*/



/*
    Step 2:  Define the call table

    A call table is an array of entries of type call_tbl_t.  Each entry has
    6 fields which must be initialized:
        1.  link field - should always be initialized to NULL.
        2.  name length - should always be initialized to 0.
        3.  minimum number of arguments to the routine
        4.  maximum number of arguments to the routine
        5.  function - the entry point for the routine
        6.  function name - the name by which to call the routine from COBOL


    For example the screen handler routines are initialized using the
    following call table:

#define SD_CALL_COUNT    22

call_tbl_t
    sd_call_tbl [SD_CALL_COUNT] = {
        { NULL, 0, 1, 1, sd_control,           "sd_control"           },
        { NULL, 0, 1, 1, sd_get_control,       "sd_get_control"       },
        { NULL, 0, 0, 0, sd_turbo_full,        "sd_turbo_full"        },
        { NULL, 0, 0, 0, sd_turbo_partial,     "sd_turbo_partial"     },
        { NULL, 0, 0, 0, sd_turbo_off,         "sd_turbo_off"         },
        { NULL, 0, 0, 0, sd_enable,            "sd_enable"            },
        { NULL, 0, 0, 0, sd_disable,           "sd_disable"           },
        { NULL, 0, 0, 0, sd_redraw,            "sd_redraw"            },
        { NULL, 0, 0, 0, sd_flush,             "sd_flush"             },
        { NULL, 0, 3, 3, sd_draw_hline,        "sd_draw_hline"        },
        { NULL, 0, 3, 3, sd_draw_vline,        "sd_draw_vline"        },
        { NULL, 0, 4, 5, sd_draw_box,          "sd_draw_box"          },
        { NULL, 0, 1, 2, sd_pop_up_menu,       "sd_pop_up_menu"       },
        { NULL, 0, 0, 0, sd_remove_window,     "sd_remove_window"     },
        { NULL, 0, 0, 5, sd_new_window,        "sd_new_window"        },
        { NULL, 0, 1, 4, sd_message,           "sd_message"           },
        { NULL, 0, 1, 3, sd_error_message,     "sd_error_message"     },
        { NULL, 0, 1, 4, sd_sys_error_message, "sd_sys_error_message" },
        { NULL, 0, 1, 1, sd_get_pos,           "sd_get_pos"           },
        { NULL, 0, 1, 1, sd_get_image,         "sd_get_image"         },
        { NULL, 0, 1, 2, sd_read_char,         "sd_read_char"         },
        { NULL, 0, 2, 2, sd_return_input,      "sd_return_input"      }
    };
*/


/*
    Step 3:  Set up the init_user_bltn routine

    This routine must include a call to load_user_calls_ for each table
    that you want to initialize at the beginning of the program.  Optionally
    it may also make calls to register_user_cleanup_ if any of your
    routines need to do processing as part of program termination.

*/


/*****************************************************************************

    init_user_bltn5

    Description:
        This routine initializes the user supplied builtin functions.

    Usage:
        Called by the runtime system at initialization time.

    Parameters:
        Address of routine that adds new builtin functions.

    Result:
        status code

    Error Handling:
        Any errors returned will cause runtime initialization to fail.
*/


status_t init_user_bltn5 (
    status_t
        (*load_calls_ptr) (unsigned int call_cnt, call_tbl_t *call_tbl_ptr),
    status_t
        (*register_cleanup_ptr) (void (*fcn) (void))
    )
{

    /* Example of initializing the screen handler calls as done by the
       runtime system where no cleanup was needed:
    */

/*
    return ((*load_calls_ptr) (SD_CALL_COUNT, &sd_call_tbl [0]));
*/

}   /* init_user_bltn5 */


